@@ -8,14 +8,18 @@ import sys
 import tarfile
 from typing import Dict, List, Optional, Tuple, Union  # noqa: F401
 
+import paramiko
 import pycloudlib  # type: ignore  # noqa: F401
+import yaml
 from behave.model import Feature, Scenario
+from behave.model_core import Status
 from behave.runner import Context
 
 import features.cloud as cloud
 from features.util import (
     BUILDER_NAME_PREFIX,
     SUT,
+    UA_TMP_DIR,
     InstallationSource,
     landscape_reject_all_pending_computers,
     process_template_vars,
@@ -64,11 +68,13 @@ class UAClientBehaveConfig:
     """
 
     prefix = "UACLIENT_BEHAVE_"
+    file_config_path = "./features/config/protest.yaml"
 
     # These variables are used in .from_environ() to convert the string
     # environment variable input to the appropriate Python types for use within
     # the test framework
     boolean_options = [
+        "collect_coverage",
         "destroy_instances",
         "ephemeral_instance",
         "snapshot_strategy",
@@ -79,6 +85,9 @@ class UAClientBehaveConfig:
         "contract_token",
         "contract_token_staging",
         "contract_token_staging_expired",
+        "contract_token_staging_expired_sometimes",
+        "contract_staging_service_account_username",
+        "contract_staging_service_account_password",
         "landscape_registration_key",
         "landscape_api_access_key",
         "landscape_api_secret_key",
@@ -93,11 +102,16 @@ class UAClientBehaveConfig:
         "userdata_file",
         "check_version",
         "sbuild_chroot",
+        "wsl_pubkey_path",
+        "wsl_privkey_path",
+        "wsl_ip_address",
     ]
     redact_options = [
         "contract_token",
         "contract_token_staging",
         "contract_token_staging_expired",
+        "contract_token_staging_expired_sometimes",
+        "contract_staging_service_account_password",
         "landscape_registration_key",
         "landscape_api_access_key",
         "landscape_api_secret_key",
@@ -111,6 +125,7 @@ class UAClientBehaveConfig:
         self,
         *,
         cloud_credentials_path: Optional[str] = None,
+        collect_coverage: bool = False,
         destroy_instances: bool = True,
         ephemeral_instance: bool = False,
         snapshot_strategy: bool = False,
@@ -122,6 +137,9 @@ class UAClientBehaveConfig:
         contract_token: Optional[str] = None,
         contract_token_staging: Optional[str] = None,
         contract_token_staging_expired: Optional[str] = None,
+        contract_token_staging_expired_sometimes: Optional[str] = None,
+        contract_staging_service_account_username: Optional[str] = None,
+        contract_staging_service_account_password: Optional[str] = None,
         landscape_registration_key: Optional[str] = None,
         landscape_api_access_key: Optional[str] = None,
         landscape_api_secret_key: Optional[str] = None,
@@ -132,15 +150,28 @@ class UAClientBehaveConfig:
         userdata_file: Optional[str] = None,
         check_version: Optional[str] = None,
         sbuild_chroot: Optional[str] = None,
+        wsl_pubkey_path: Optional[str] = None,
+        wsl_privkey_path: Optional[str] = None,
+        wsl_ip_address: Optional[str] = None,
     ) -> None:
         # First, store the values we've detected
         self.cloud_credentials_path = cloud_credentials_path
+        self.collect_coverage = collect_coverage
         self.ephemeral_instance = ephemeral_instance
         self.snapshot_strategy = snapshot_strategy
         self.sbuild_output_to_terminal = sbuild_output_to_terminal
         self.contract_token = contract_token
         self.contract_token_staging = contract_token_staging
         self.contract_token_staging_expired = contract_token_staging_expired
+        self.contract_token_staging_expired_sometimes = (
+            contract_token_staging_expired_sometimes
+        )
+        self.contract_staging_service_account_username = (
+            contract_staging_service_account_username
+        )
+        self.contract_staging_service_account_password = (
+            contract_staging_service_account_password
+        )
         self.landscape_registration_key = landscape_registration_key
         self.landscape_api_access_key = landscape_api_access_key
         self.landscape_api_secret_key = landscape_api_secret_key
@@ -154,6 +185,10 @@ class UAClientBehaveConfig:
         self.userdata_file = userdata_file
         self.check_version = check_version
         self.sbuild_chroot = sbuild_chroot
+        self.wsl_pubkey_path = wsl_pubkey_path
+        self.wsl_privkey_path = wsl_privkey_path
+        self.wsl_ip_address = wsl_ip_address
+
         self.machine_types = (
             machine_types.split(",") if machine_types else None
         )
@@ -229,12 +264,25 @@ class UAClientBehaveConfig:
 
     @classmethod
     def from_environ(cls, config) -> "UAClientBehaveConfig":
-        """Gather config options from os.environ and return a config object"""
+        """Gather config options from:
+
+        1. features/config/protest.yaml
+        2. os.environ with prefix UACLIENT_BEHAVE_
+        3. -D command line options
+
+        each of which can override the previous.
+        """
         # First, gather all known options
         kwargs = (
             {}
         )  # type: Dict[str, Union[str, bool, List, InstallationSource]]
 
+        try:
+            with open(cls.file_config_path) as file_config:
+                kwargs = yaml.safe_load(file_config)
+        except FileNotFoundError:
+            print("No config file found at {}".format(cls.file_config_path))
+
         for key, value in os.environ.items():
             if not key.startswith(cls.prefix):
                 continue
@@ -402,8 +450,106 @@ def before_scenario(context: Context, scenario: Scenario):
             )
 
 
+def after_scenario(context, scenario):
+    """Collect the coverage files after the scenario is run."""
+    if context.pro_config.collect_coverage:
+        cov_dir = os.path.join(context.pro_config.artifact_dir, "coverage")
+        os.makedirs(cov_dir, exist_ok=True)
+
+        inner_dir = os.path.basename(scenario.filename.replace(".", "_"))
+        new_artifacts_dir = os.path.join(
+            cov_dir,
+            inner_dir,
+        )
+        os.makedirs(new_artifacts_dir, exist_ok=True)
+        if hasattr(context, "machines") and SUT in context.machines:
+            try:
+                scenario_name = (
+                    os.path.basename(scenario.filename.replace(".", "_"))
+                    + "_"
+                    + str(scenario.line)
+                )
+                cov_filename = ".coverage.{}".format(scenario_name)
+                tmp_covfile_path = "/tmp/{cov_filename}".format(
+                    cov_filename=cov_filename
+                )
+                context.machines[SUT].instance.execute(
+                    [
+                        "mv",
+                        "/home/ubuntu/.coverage",
+                        tmp_covfile_path,
+                    ],
+                    use_sudo=True,
+                )
+                context.machines[SUT].instance.execute(
+                    [
+                        "chmod",
+                        "666",
+                        tmp_covfile_path,
+                    ],
+                    use_sudo=True,
+                )
+
+                dest = os.path.join(new_artifacts_dir, cov_filename)
+                context.machines[SUT].instance.pull_file(
+                    tmp_covfile_path, dest
+                )
+                logging.warning("Done collecting coverage.")
+            except Exception as e:
+                logging.error(str(e))
+                logging.warning("Failed to collect coverage")
+
+
+def _get_relevant_apparmor_logs(context):
+    if hasattr(context, "machines") and SUT in context.machines:
+        sut = context.machines[SUT]
+        if sut.cloud == "lxd-container":
+            # get apparmor DENIED messages from the host
+            with open("/var/log/syslog", "r") as syslog_fd:
+                syslog_messages = syslog_fd.readlines()
+            apparmor_denied = [
+                msg.strip()
+                for msg in syslog_messages
+                if (
+                    "DENIED" in msg
+                    and "ubuntu_pro_" in msg
+                    and sut.instance.name in msg
+                )
+            ]
+            return apparmor_denied
+        else:
+            # get apparmor DENIED messages from the SUT
+            os.makedirs(UA_TMP_DIR, exist_ok=True)
+            syslog_dest = os.path.join(
+                UA_TMP_DIR, "{}-syslog".format(sut.instance.name)
+            )
+            try:
+                sut.instance.pull_file("/var/log/syslog", syslog_dest)
+            except paramiko.ssh_exception.SSHException:
+                logging.warning(
+                    "Unable to pull syslog. Skipping apparmor log check."
+                )
+                return None
+            with open(syslog_dest, "r") as syslog_fd:
+                syslog_messages = syslog_fd.readlines()
+            apparmor_denied = [
+                msg.strip()
+                for msg in syslog_messages
+                if ("DENIED" in msg and "ubuntu_pro_" in msg)
+            ]
+            return apparmor_denied
+    return None
+
+
 def after_step(context, step):
     """Collect test artifacts in the event of failure."""
+    apparmor_logs = _get_relevant_apparmor_logs(context)
+    if apparmor_logs:
+        logging.warning("XXX apparmor DENIED begin")
+        logging.warning("\n".join(apparmor_logs))
+        logging.warning("XXX apparmor DENIED end")
+        # naughty
+        step.status = Status.failed
     if step.status == "failed":
         logging.warning("STEP FAILED. Collecting logs.")
         inner_dir = os.path.join(
@@ -471,6 +617,10 @@ def after_all(context):
                 "Failed to delete instance ssh keys:\n{}".format(str(e))
             )
 
+        if context.pro_config.clouds.has("wsl"):
+            cloud_instance = context.pro_config.clouds.get("wsl")
+            cloud_instance.stop_windows_machine()
+
     # Builder snapshots don't get an auto-cleanup function, so clean them here
     builder_snapshots = [
         name
