@@ -6,6 +6,7 @@ from typing import NamedTuple
 from behave import given, when
 from pycloudlib.instance import BaseInstance  # type: ignore
 
+from features.steps.packages import when_i_apt_install, when_i_apt_update
 from features.steps.shell import when_i_run_command
 from features.steps.ubuntu_advantage_tools import when_i_install_uat
 from features.util import (
@@ -106,6 +107,23 @@ def given_a_machine(
             machine_name=machine_name,
         )
 
+    # make sure the machine has up-to-date apt data
+    when_i_apt_update(context, machine_name=machine_name)
+
+    # add coverage
+    if context.pro_config.collect_coverage:
+        when_i_apt_install(
+            context, "python3-coverage", machine_name=machine_name
+        )
+
+    # trigger GH: #3137
+    when_i_run_command(
+        context,
+        "touch /var/lib/dpkg/arch",
+        "with sudo",
+        machine_name=machine_name,
+    )
+
     if cleanup:
 
         def cleanup_instance():
@@ -154,6 +172,22 @@ def when_i_take_a_snapshot(context, machine_name=SUT, cleanup=True):
         context.add_cleanup(cleanup_snapshot)
 
 
+def _update_distro_info_data(context, machine_name=SUT):
+    # There is a problem on Xenial where distro-info-data was incorrectly
+    # saying that Xenial was only supported until 2024. The fix was
+    # SRUed to Xenial, but now we need to guarantee that we run our tests
+    # on the latest version of that package. Additionally, we don't see
+    # a problem of always upgrading that package for every release.
+    when_i_run_command(
+        context,
+        "apt install distro-info-data -y",
+        "with sudo",
+        machine_name=machine_name,
+    )
+    # And this will kick of the ESM cache setup
+    when_i_apt_update(context, machine_name=machine_name)
+
+
 @given(
     "a `{series}` `{machine_type}` machine with ubuntu-advantage-tools installed"  # noqa: E501
 )
@@ -179,7 +213,7 @@ def given_a_sut_machine(context, series, machine_type):
             )
             sys.exit(1)
 
-    builder_name = BUILDER_NAME_PREFIX + machine_type
+    builder_name = BUILDER_NAME_PREFIX + machine_type + "-" + series
 
     if context.pro_config.snapshot_strategy:
         if builder_name not in context.snapshots:
@@ -190,6 +224,7 @@ def given_a_sut_machine(context, series, machine_type):
                 machine_name=builder_name,
                 cleanup=False,
             )
+            _update_distro_info_data(context, machine_name=builder_name)
             when_i_install_uat(context, machine_name=builder_name)
             when_i_take_a_snapshot(
                 context,
@@ -205,6 +240,7 @@ def given_a_sut_machine(context, series, machine_type):
         )
     else:
         given_a_machine(context, series, machine_type=machine_type)
+        _update_distro_info_data(context)
         when_i_install_uat(context)
 
     logging.info(
