@@ -3,32 +3,20 @@ import io
 import json
 import logging
 import socket
-import sys
 import textwrap
 
 import mock
 import pytest
 
 from uaclient import defaults, exceptions, messages, status
-from uaclient.cli import (
-    action_help,
-    assert_attached,
-    assert_lock_file,
-    assert_not_attached,
-    assert_root,
-    get_parser,
-    main,
-    setup_logging,
-)
+from uaclient.cli import action_help, get_parser, main
 from uaclient.entitlements import get_valid_entitlement_names
 from uaclient.exceptions import (
     AlreadyAttachedError,
     LockHeldError,
-    NonRootUserError,
     UbuntuProError,
     UnattachedError,
 )
-from uaclient.files.notices import Notice
 
 BIG_DESC = "123456789 " * 7 + "next line"
 BIG_URL = "http://" + "adsf" * 10
@@ -105,7 +93,7 @@ def get_help(request, capsys, FakeConfig):
                     "uaclient.config.UAConfig",
                     return_value=FakeConfig(),
                 ):
-                    with mock.patch("uaclient.cli.setup_logging"):
+                    with mock.patch("uaclient.log.setup_cli_logging"):
                         main()
             out, _err = capsys.readouterr()
 
@@ -356,150 +344,23 @@ class TestCLIParser:
 M_PATH_UACONFIG = "uaclient.config.UAConfig."
 
 
-class TestAssertLockFile:
-    @mock.patch("os.getpid", return_value=123)
-    @mock.patch(M_PATH_UACONFIG + "delete_cache_key")
-    @mock.patch("uaclient.files.notices.NoticesManager.add")
-    @mock.patch(M_PATH_UACONFIG + "write_cache")
-    def test_assert_root_creates_lock_and_notice(
-        self,
-        m_write_cache,
-        m_add_notice,
-        m_delete_cache,
-        _m_getpid,
-        FakeConfig,
-    ):
-        arg, kwarg = mock.sentinel.arg, mock.sentinel.kwarg
-
-        @assert_lock_file("some operation")
-        def test_function(args, cfg):
-            assert arg == mock.sentinel.arg
-            assert kwarg == mock.sentinel.kwarg
-
-            return mock.sentinel.success
-
-        ret = test_function(arg, cfg=FakeConfig())
-        assert mock.sentinel.success == ret
-        lock_msg = "Operation in progress: some operation"
-        assert [
-            mock.call(Notice.OPERATION_IN_PROGRESS, lock_msg)
-        ] == m_add_notice.call_args_list
-        assert [mock.call("lock")] == m_delete_cache.call_args_list
-        assert [
-            mock.call("lock", "123:some operation")
-        ] == m_write_cache.call_args_list
-
-
-class TestAssertRoot:
-    def test_assert_root_when_root(self):
-        # autouse mock for we_are_currently_root defaults it to True
-        arg, kwarg = mock.sentinel.arg, mock.sentinel.kwarg
-
-        @assert_root
-        def test_function(arg, *, kwarg):
-            assert arg == mock.sentinel.arg
-            assert kwarg == mock.sentinel.kwarg
-
-            return mock.sentinel.success
-
-        ret = test_function(arg, kwarg=kwarg)
-
-        assert mock.sentinel.success == ret
-
-    def test_assert_root_when_not_root(self):
-        @assert_root
-        def test_function():
-            pass
-
-        with mock.patch(
-            "uaclient.cli.util.we_are_currently_root", return_value=False
-        ):
-            with pytest.raises(NonRootUserError):
-                test_function()
-
-
-# Test multiple uids, to be sure that the root checking is absent
-@pytest.mark.parametrize("root", [True, False])
-class TestAssertAttached:
-    def test_assert_attached_when_attached(self, capsys, root, FakeConfig):
-        @assert_attached()
-        def test_function(args, cfg):
-            return mock.sentinel.success
-
-        cfg = FakeConfig.for_attached_machine()
-
-        with mock.patch(
-            "uaclient.cli.util.we_are_currently_root", return_value=root
-        ):
-            ret = test_function(mock.Mock(), cfg)
-
-        assert mock.sentinel.success == ret
-
-        out, _err = capsys.readouterr()
-        assert "" == out.strip()
-
-    def test_assert_attached_when_unattached(self, root, FakeConfig):
-        @assert_attached()
-        def test_function(args, cfg):
-            pass
-
-        cfg = FakeConfig()
-
-        with mock.patch(
-            "uaclient.cli.util.we_are_currently_root", return_value=root
-        ):
-            with pytest.raises(UnattachedError):
-                test_function(mock.Mock(), cfg)
-
-
-@pytest.mark.parametrize("root", [True, False])
-class TestAssertNotAttached:
-    def test_when_attached(self, root, FakeConfig):
-        @assert_not_attached
-        def test_function(args, cfg):
-            pass
-
-        cfg = FakeConfig.for_attached_machine()
-
-        with mock.patch(
-            "uaclient.cli.util.we_are_currently_root", return_value=root
-        ):
-            with pytest.raises(AlreadyAttachedError):
-                test_function(mock.Mock(), cfg)
-
-    def test_when_not_attached(self, capsys, root, FakeConfig):
-        @assert_not_attached
-        def test_function(args, cfg):
-            return mock.sentinel.success
-
-        cfg = FakeConfig()
-
-        with mock.patch(
-            "uaclient.cli.util.we_are_currently_root", return_value=root
-        ):
-            ret = test_function(mock.Mock(), cfg)
-
-        assert mock.sentinel.success == ret
-
-        out, _err = capsys.readouterr()
-        assert "" == out.strip()
-
-
 class TestMain:
     @pytest.mark.parametrize(
         "exception,expected_error_msg,expected_log",
         (
             (
                 TypeError("'NoneType' object is not subscriptable"),
-                messages.UNEXPECTED_ERROR.msg,
+                messages.UNEXPECTED_ERROR.format(
+                    error_msg="'NoneType' object is not subscriptable",
+                    log_path="/var/log/ubuntu-advantage.log",
+                ),
                 "Unhandled exception, please file a bug",
             ),
         ),
     )
-    @mock.patch(M_PATH_UACONFIG + "delete_cache_key")
     @mock.patch("uaclient.cli.event.info")
     @mock.patch("uaclient.cli.LOG.exception")
-    @mock.patch("uaclient.cli.setup_logging")
+    @mock.patch("uaclient.log.setup_cli_logging")
     @mock.patch("uaclient.cli.get_parser")
     def test_errors_handled_gracefully(
         self,
@@ -507,7 +368,6 @@ class TestMain:
         _m_setup_logging,
         m_log_exception,
         m_event_info,
-        m_delete_cache_key,
         event,
         exception,
         expected_error_msg,
@@ -524,13 +384,11 @@ class TestMain:
                     return_value=FakeConfig(),
                 ):
                     main()
-        assert 0 == m_delete_cache_key.call_count
 
         exc = excinfo.value
         assert 1 == exc.code
-
         assert [
-            mock.call(info_msg=expected_error_msg, file_type=mock.ANY)
+            mock.call(info_msg=expected_error_msg.msg, file_type=mock.ANY)
         ] == m_event_info.call_args_list
         assert [mock.call(expected_log)] == m_log_exception.call_args_list
 
@@ -543,16 +401,14 @@ class TestMain:
             ),
         ),
     )
-    @mock.patch(M_PATH_UACONFIG + "delete_cache_key")
     @mock.patch("uaclient.cli.LOG.error")
-    @mock.patch("uaclient.cli.setup_logging")
+    @mock.patch("uaclient.log.setup_cli_logging")
     @mock.patch("uaclient.cli.get_parser")
     def test_interrupt_errors_handled_gracefully(
         self,
         m_get_parser,
         _m_setup_logging,
         m_log_error,
-        m_delete_cache_key,
         exception,
         expected_log,
         FakeConfig,
@@ -567,7 +423,6 @@ class TestMain:
                     return_value=FakeConfig(),
                 ):
                     main()
-        assert 0 == m_delete_cache_key.call_count
 
         exc = excinfo.value
         assert 1 == exc.code
@@ -591,7 +446,7 @@ class TestMain:
     )
     @mock.patch("uaclient.cli.event.info")
     @mock.patch("uaclient.cli.LOG.error")
-    @mock.patch("uaclient.cli.setup_logging")
+    @mock.patch("uaclient.log.setup_cli_logging")
     @mock.patch("uaclient.cli.get_parser")
     def test_user_facing_error_handled_gracefully(
         self,
@@ -633,7 +488,7 @@ class TestMain:
     )
     @mock.patch("uaclient.cli.event.info")
     @mock.patch("uaclient.cli.LOG.exception")
-    @mock.patch("uaclient.cli.setup_logging")
+    @mock.patch("uaclient.log.setup_cli_logging")
     @mock.patch("uaclient.cli.get_parser")
     def test_url_error_handled_gracefully(
         self,
@@ -668,7 +523,7 @@ class TestMain:
         assert [expected_log_call] == m_log_exception.call_args_list
 
     @pytest.mark.parametrize("caplog_text", [logging.DEBUG], indirect=True)
-    @mock.patch("uaclient.cli.setup_logging")
+    @mock.patch("uaclient.log.setup_cli_logging")
     @mock.patch("uaclient.cli.get_parser")
     def test_command_line_is_logged(
         self, _m_get_parser, _m_setup_logging, caplog_text
@@ -680,7 +535,7 @@ class TestMain:
         assert "['some', 'args']" in log
 
     @pytest.mark.parametrize("caplog_text", [logging.DEBUG], indirect=True)
-    @mock.patch("uaclient.cli.setup_logging")
+    @mock.patch("uaclient.log.setup_cli_logging")
     @mock.patch("uaclient.cli.get_parser")
     @mock.patch(
         "uaclient.cli.util.get_pro_environment",
@@ -700,7 +555,7 @@ class TestMain:
         assert "UA_ENV=YES" in log
         assert "UA_FEATURES_WOW=XYZ" in log
 
-    @mock.patch("uaclient.cli.setup_logging")
+    @mock.patch("uaclient.log.setup_cli_logging")
     @mock.patch("uaclient.cli.get_parser")
     @mock.patch("uaclient.cli.config.UAConfig")
     @pytest.mark.parametrize("config_error", [True, False])
@@ -776,7 +631,7 @@ class TestMain:
     @mock.patch("uaclient.cli.event.info")
     @mock.patch("uaclient.cli.action_status")
     @mock.patch("uaclient.cli.action_security_status")
-    @mock.patch("uaclient.cli.setup_logging")
+    @mock.patch("uaclient.log.setup_cli_logging")
     @mock.patch("sys.stdout.isatty")
     def test_status_human_readable_warning(
         self,
@@ -811,39 +666,6 @@ class TestMain:
             assert [] == m_event_info.call_args_list
 
 
-class TestSetupLogging:
-    def test_correct_handlers_added_to_logger(
-        self,
-        FakeConfig,
-    ):
-        log_level = logging.DEBUG
-        logger = logging.getLogger("logger_a")
-
-        handler = logging.StreamHandler(sys.stderr)
-        handler.setLevel(logging.ERROR)
-        handler.set_name("ua-test-console")
-        logger.addHandler(handler)
-
-        with mock.patch(
-            "uaclient.cli.config.UAConfig", return_value=FakeConfig()
-        ):
-            setup_logging(log_level, logger=logger)
-        assert len(logger.handlers) == 1
-        assert logger.handlers[0].name == "upro-file"
-        assert logger.handlers[0].level == log_level
-
-    @mock.patch("pathlib.Path.touch")
-    def test_log_file_created_if_not_present(self, m_path_touch, tmpdir):
-        logger = logging.getLogger("logger_b")
-        log_file = tmpdir.join("log_file").strpath
-        setup_logging(
-            logging.INFO,
-            log_file=log_file,
-            logger=logger,
-        )
-        assert m_path_touch.call_args_list == [mock.call(mode=0o640)]
-
-
 class TestGetValidEntitlementNames:
     @mock.patch(
         "uaclient.cli.entitlements.valid_services",
