@@ -7,7 +7,7 @@ import textwrap
 import mock
 import pytest
 
-from uaclient import event_logger, http, messages, util
+from uaclient import event_logger, http, lock, messages, util
 from uaclient.cli import (
     _post_cli_attach,
     action_attach,
@@ -24,6 +24,7 @@ from uaclient.exceptions import (
     NonRootUserError,
     UbuntuProError,
 )
+from uaclient.files.user_config_file import UserConfigData
 from uaclient.testing.fakes import FakeFile, FakeUbuntuProError
 from uaclient.yaml import safe_dump
 
@@ -177,49 +178,44 @@ class TestActionAttach:
         }
         assert expected == json.loads(capsys.readouterr()[0])
 
+    @mock.patch("uaclient.lock.check_lock_info")
     @mock.patch("time.sleep")
     @mock.patch("uaclient.system.subp")
     def test_lock_file_exists(
         self,
         m_subp,
         m_sleep,
+        m_check_lock_info,
         capsys,
         FakeConfig,
         event,
     ):
-        """Check when an operation holds a lock file, attach cannot run."""
         cfg = FakeConfig()
-        cfg.write_cache("lock", "123:pro disable")
+        m_check_lock_info.return_value = (123, "pro disable")
+        expected_msg = messages.E_LOCK_HELD_ERROR.format(
+            lock_request="pro attach", lock_holder="pro disable", pid=123
+        )
+        """Check when an operation holds a lock file, attach cannot run."""
         with pytest.raises(LockHeldError) as exc_info:
             action_attach(mock.MagicMock(), cfg=cfg)
-        assert [mock.call(["ps", "123"])] * 12 == m_subp.call_args_list
-        assert (
-            "Unable to perform: pro attach.\n"
-            "Operation in progress: pro disable (pid:123)"
-        ) == exc_info.value.msg
+        assert 12 == m_check_lock_info.call_count
+        assert expected_msg.msg == exc_info.value.msg
 
         with pytest.raises(SystemExit):
             with mock.patch.object(
                 event, "_event_logger_mode", event_logger.EventLoggerMode.JSON
             ):
-                with mock.patch.object(
-                    cfg, "check_lock_info"
-                ) as m_check_lock_info:
-                    m_check_lock_info.return_value = (1, "lock_holder")
-                    main_error_handler(action_attach)(mock.MagicMock(), cfg)
+                main_error_handler(action_attach)(mock.MagicMock(), cfg)
 
-        expected_msg = messages.E_LOCK_HELD_ERROR.format(
-            lock_request="pro attach", lock_holder="lock_holder", pid=1
-        )
         expected = {
             "_schema_version": event_logger.JSON_SCHEMA_VERSION,
             "result": "failure",
             "errors": [
                 {
                     "additional_info": {
-                        "lock_holder": "lock_holder",
+                        "lock_holder": "pro disable",
                         "lock_request": "pro attach",
-                        "pid": 1,
+                        "pid": 123,
                     },
                     "message": expected_msg.msg,
                     "message_code": expected_msg.name,
@@ -253,9 +249,15 @@ class TestActionAttach:
         assert "This machine is now attached to 'test_contract'" in out
         assert "mock_tabular_status" in out
 
+    @mock.patch("uaclient.lock.check_lock_info", return_value=(-1, ""))
+    @mock.patch(
+        "uaclient.entitlements.check_entitlement_apt_directives_are_unique",
+        return_value=True,
+    )
     @mock.patch(
         M_PATH + "contract.UAContractClient.update_activity_token",
     )
+    @mock.patch("uaclient.files.state_files.machine_id_file.write")
     @mock.patch("uaclient.files.state_files.attachment_data_file.write")
     @mock.patch("uaclient.system.should_reboot", return_value=False)
     @mock.patch("uaclient.files.notices.NoticesManager.remove")
@@ -270,7 +272,10 @@ class TestActionAttach:
         _m_remove_notice,
         _m_should_reboot,
         _m_attachment_data_file_write,
+        _m_machine_id_file_write,
         m_update_activity_token,
+        _m_check_ent_apt_directives,
+        _m_check_lock_info,
         FakeConfig,
         event,
     ):
@@ -287,7 +292,8 @@ class TestActionAttach:
 
         contract_machine_attach.side_effect = fake_contract_attach
 
-        ret = action_attach(args, cfg)
+        with mock.patch.object(lock, "lock_data_file"):
+            ret = action_attach(args, cfg)
 
         assert 0 == ret
         expected_calls = [
@@ -299,6 +305,7 @@ class TestActionAttach:
         assert [mock.call(cfg)] == m_post_cli.call_args_list
 
     @pytest.mark.parametrize("auto_enable", (True, False))
+    @mock.patch("uaclient.lock.check_lock_info", return_value=(-1, ""))
     @mock.patch(
         M_PATH + "contract.UAContractClient.update_activity_token",
     )
@@ -319,6 +326,7 @@ class TestActionAttach:
         _m_should_reboot,
         _m_attachment_data_file_write,
         _m_update_activity_token,
+        _m_check_lock_info,
         auto_enable,
         FakeConfig,
     ):
@@ -327,14 +335,17 @@ class TestActionAttach:
         )
 
         cfg = FakeConfig()
-        action_attach(args, cfg)
+        with mock.patch.object(lock, "lock_data_file"):
+            action_attach(args, cfg)
 
         assert [
             mock.call(mock.ANY, token="token", allow_enable=auto_enable)
         ] == m_attach_with_token.call_args_list
 
+    @mock.patch("uaclient.lock.check_lock_info", return_value=(-1, ""))
     def test_attach_config_and_token_mutually_exclusive(
         self,
+        _m_check_lock_info,
         FakeConfig,
     ):
         args = mock.MagicMock(
@@ -342,9 +353,12 @@ class TestActionAttach:
         )
         cfg = FakeConfig()
         with pytest.raises(UbuntuProError) as e:
-            action_attach(args, cfg=cfg)
+            with mock.patch.object(lock, "lock_data_file"):
+                action_attach(args, cfg=cfg)
+
         assert e.value.msg == messages.E_ATTACH_TOKEN_ARG_XOR_CONFIG.msg
 
+    @mock.patch("uaclient.lock.check_lock_info", return_value=(-1, ""))
     @mock.patch(
         M_PATH + "contract.UAContractClient.update_activity_token",
     )
@@ -355,6 +369,7 @@ class TestActionAttach:
         m_attach_with_token,
         _m_post_cli_attach,
         m_update_activity_token,
+        _m_check_lock_info,
         FakeConfig,
     ):
         args = mock.MagicMock(
@@ -362,14 +377,18 @@ class TestActionAttach:
             attach_config=FakeFile(safe_dump({"token": "faketoken"})),
         )
         cfg = FakeConfig()
-        action_attach(args, cfg=cfg)
+        with mock.patch.object(lock, "lock_data_file"):
+            action_attach(args, cfg=cfg)
+
         assert [
             mock.call(mock.ANY, token="faketoken", allow_enable=True)
         ] == m_attach_with_token.call_args_list
         assert 1 == m_update_activity_token.call_count
 
+    @mock.patch("uaclient.lock.check_lock_info", return_value=(-1, ""))
     def test_attach_config_invalid_config(
         self,
+        _m_check_lock_info,
         FakeConfig,
         capsys,
         event,
@@ -383,7 +402,8 @@ class TestActionAttach:
         )
         cfg = FakeConfig()
         with pytest.raises(UbuntuProError) as e:
-            action_attach(args, cfg=cfg)
+            with mock.patch.object(lock, "lock_data_file"):
+                action_attach(args, cfg=cfg)
         assert "Error while reading fakename:" in e.value.msg
 
         args.attach_config = FakeFile(
@@ -394,7 +414,8 @@ class TestActionAttach:
             with mock.patch.object(
                 event, "_event_logger_mode", event_logger.EventLoggerMode.JSON
             ):
-                main_error_handler(action_attach)(args, cfg)
+                with mock.patch.object(lock, "lock_data_file"):
+                    main_error_handler(action_attach)(args, cfg)
 
         expected_message = messages.E_ATTACH_CONFIG_READ_ERROR.format(
             config_name="fakename",
@@ -432,6 +453,7 @@ class TestActionAttach:
         assert expected == json.loads(capsys.readouterr()[0])
 
     @pytest.mark.parametrize("auto_enable", (True, False))
+    @mock.patch("uaclient.lock.check_lock_info", return_value=(-1, ""))
     @mock.patch(
         M_PATH + "contract.UAContractClient.update_activity_token",
     )
@@ -455,6 +477,7 @@ class TestActionAttach:
         m_attach_with_token,
         m_enable,
         m_update_activity_token,
+        _m_check_lock_info,
         auto_enable,
         FakeConfig,
         event,
@@ -471,7 +494,9 @@ class TestActionAttach:
             ),
             auto_enable=auto_enable,
         )
-        action_attach(args, cfg=cfg)
+        with mock.patch.object(lock, "lock_data_file"):
+            action_attach(args, cfg=cfg)
+
         assert [
             mock.call(mock.ANY, token="faketoken", allow_enable=False)
         ] == m_attach_with_token.call_args_list
@@ -492,7 +517,8 @@ class TestActionAttach:
             with mock.patch.object(
                 event, "_event_logger_mode", event_logger.EventLoggerMode.JSON
             ):
-                main_error_handler(action_attach)(args, cfg)
+                with mock.patch.object(lock, "lock_data_file"):
+                    main_error_handler(action_attach)(args, cfg)
 
         expected = {
             "_schema_version": event_logger.JSON_SCHEMA_VERSION,
@@ -515,25 +541,51 @@ class TestActionAttach:
             ),
             (
                 Exception("error"),
-                messages.UNEXPECTED_ERROR,
+                messages.UNEXPECTED_ERROR.format(
+                    error_msg="error",
+                    log_path="/var/log/ubuntu-advantage.log",
+                ),
                 messages.E_ATTACH_FAILURE_UNEXPECTED,
             ),
         ),
     )
+    @mock.patch("uaclient.files.state_files.status_cache_file.write")
+    @mock.patch("uaclient.lock.check_lock_info", return_value=(-1, ""))
+    @mock.patch(
+        "uaclient.entitlements.check_entitlement_apt_directives_are_unique",
+        return_value=True,
+    )
+    @mock.patch(
+        "uaclient.files.state_files.machine_id_file.read", return_value=None
+    )
+    @mock.patch("uaclient.files.state_files.machine_id_file.write")
     @mock.patch("uaclient.files.state_files.attachment_data_file.write")
     @mock.patch("uaclient.entitlements.entitlements_enable_order")
-    @mock.patch("uaclient.contract.process_entitlement_delta")
+    @mock.patch("uaclient.actions.enable_entitlement_by_name")
+    @mock.patch("uaclient.contract.get_enabled_by_default_services")
     @mock.patch("uaclient.contract.apply_contract_overrides")
     @mock.patch("uaclient.contract.UAContractClient.request_url")
     @mock.patch("uaclient.timer.update_messaging.update_motd_messages")
+    @mock.patch(
+        "uaclient.files.user_config_file.UserConfigFileObject.public_config",
+        new_callable=mock.PropertyMock,
+        return_value=UserConfigData(),
+    )
     def test_attach_when_one_service_fails_to_enable(
         self,
+        m_public_config,
         _m_update_messages,
         m_request_url,
         _m_apply_contract_overrides,
-        m_process_entitlement_delta,
+        m_get_enabled_by_default_services,
+        m_enable_ent_by_name,
         m_enable_order,
         _m_attachment_data_file_write,
+        _m_machine_id_file_write,
+        _m_machine_id_file_read,
+        _m_check_ent_apt_directives,
+        _m_check_lock_info,
+        _m_status_cache_file,
         expected_exception,
         expected_msg,
         expected_outer_msg,
@@ -544,10 +596,17 @@ class TestActionAttach:
         cfg = FakeConfig()
 
         m_enable_order.return_value = ["test1", "test2"]
-        m_process_entitlement_delta.side_effect = [
-            ({"test": 123}, True),
+        m_enable_ent_by_name.side_effect = [
+            (True, None),
             expected_exception,
         ]
+        m_ent1 = mock.MagicMock(variant="")
+        type(m_ent1).name = mock.PropertyMock(return_value="test1")
+
+        m_ent2 = mock.MagicMock(variant="")
+        type(m_ent2).name = mock.PropertyMock(return_value="test2")
+
+        m_get_enabled_by_default_services.return_value = [m_ent1, m_ent2]
         m_request_url.return_value = http.HTTPResponse(
             code=200,
             headers={},
@@ -591,7 +650,8 @@ class TestActionAttach:
                     "_event_logger_mode",
                     event_logger.EventLoggerMode.JSON,
                 ):
-                    main_error_handler(action_attach)(args, cfg)
+                    with mock.patch.object(lock, "lock_data_file"):
+                        main_error_handler(action_attach)(args, cfg)
 
         expected = {
             "_schema_version": event_logger.JSON_SCHEMA_VERSION,
@@ -620,6 +680,7 @@ class TestActionAttach:
         }
         assert expected == json.loads(fake_stdout.getvalue())
 
+    @mock.patch("uaclient.lock.check_lock_info", return_value=(-1, ""))
     @mock.patch(M_PATH + "_initiate")
     @mock.patch(M_PATH + "_wait")
     @mock.patch(M_PATH + "_revoke")
@@ -628,6 +689,7 @@ class TestActionAttach:
         m_revoke,
         m_wait,
         m_initiate,
+        _m_check_lock_info,
         FakeConfig,
     ):
         m_initiate.return_value = mock.MagicMock(
@@ -637,17 +699,22 @@ class TestActionAttach:
         m_args = mock.MagicMock(token=None, attach_config=None)
 
         with pytest.raises(MagicAttachTokenError):
-            action_attach(args=m_args, cfg=FakeConfig())
+            with mock.patch.object(lock, "lock_data_file"):
+                action_attach(args=m_args, cfg=FakeConfig())
 
         assert 1 == m_initiate.call_count
         assert 1 == m_wait.call_count
         assert 1 == m_revoke.call_count
 
-    def test_magic_attach_fails_if_format_json_param_used(self, FakeConfig):
+    @mock.patch("uaclient.lock.check_lock_info", return_value=(-1, ""))
+    def test_magic_attach_fails_if_format_json_param_used(
+        self, _m_check_lock_info, FakeConfig
+    ):
         m_args = mock.MagicMock(token=None, attach_config=None, format="json")
 
         with pytest.raises(MagicAttachInvalidParam) as exc_info:
-            action_attach(args=m_args, cfg=FakeConfig())
+            with mock.patch.object(lock, "lock_data_file"):
+                action_attach(args=m_args, cfg=FakeConfig())
 
         assert (
             "This attach flow does not support --format with value: json"
@@ -656,7 +723,7 @@ class TestActionAttach:
 
 @mock.patch(M_PATH + "contract.get_available_resources")
 class TestParser:
-    @mock.patch("uaclient.cli.setup_logging")
+    @mock.patch("uaclient.log.setup_cli_logging")
     def test_attach_help(
         self, _m_resources, _m_setup_logging, capsys, FakeConfig
     ):
