@@ -6,12 +6,18 @@ import textwrap
 import mock
 import pytest
 
-from uaclient import entitlements, event_logger, exceptions, messages
-from uaclient.cli import action_disable, main, main_error_handler
+from uaclient import entitlements, event_logger, exceptions, lock, messages
+from uaclient.api.u.pro.services.dependencies.v1 import (
+    ServiceWithDependencies,
+    ServiceWithReason,
+)
+from uaclient.cli import main, main_error_handler
+from uaclient.cli.disable import action_disable, prompt_for_dependency_handling
 from uaclient.entitlements.entitlement_status import (
     CanDisableFailure,
     CanDisableFailureReason,
 )
+from uaclient.testing.helpers import does_not_raise
 
 
 @pytest.fixture
@@ -55,7 +61,7 @@ Flags:
 
 
 class TestDisable:
-    @mock.patch("uaclient.cli.setup_logging")
+    @mock.patch("uaclient.log.setup_cli_logging")
     @mock.patch("uaclient.cli.contract.get_available_resources")
     def test_disable_help(
         self, _m_resources, _m_setup_logging, capsys, FakeConfig
@@ -75,6 +81,7 @@ class TestDisable:
     @pytest.mark.parametrize(
         "disable_return,return_code", ((True, 0), (False, 1))
     )
+    @mock.patch("uaclient.lock.check_lock_info", return_value=(-1, ""))
     @mock.patch(
         "uaclient.cli.contract.UAContractClient.update_activity_token",
     )
@@ -87,6 +94,7 @@ class TestDisable:
         m_valid_services,
         m_entitlement_factory,
         m_update_activity_token,
+        _m_check_lock_info,
         disable_return,
         return_code,
         assume_yes,
@@ -123,6 +131,7 @@ class TestDisable:
             type(m_entitlement).name = mock.PropertyMock(
                 return_value=entitlement_name
             )
+            m_entitlement._check_for_reboot.return_value = False
 
         def factory_side_effect(cfg, name, ent_dict=ent_dict):
             return ent_dict.get(name)
@@ -135,7 +144,7 @@ class TestDisable:
         args_mock.assume_yes = assume_yes
         args_mock.purge = False
 
-        with mock.patch.object(cfg, "check_lock_info", return_value=(-1, "")):
+        with mock.patch.object(lock, "lock_data_file"):
             ret = action_disable(args_mock, cfg=cfg)
 
         for m_entitlement_cls in entitlements_cls:
@@ -143,7 +152,7 @@ class TestDisable:
                 mock.call(cfg, assume_yes=assume_yes, purge=False)
             ] == m_entitlement_cls.call_args_list
 
-        expected_disable_call = mock.call()
+        expected_disable_call = mock.call(mock.ANY)
         for m_entitlement in entitlements_obj:
             assert [
                 expected_disable_call
@@ -160,9 +169,7 @@ class TestDisable:
             event, "_event_logger_mode", event_logger.EventLoggerMode.JSON
         ):
             with mock.patch.object(event, "set_event_mode"):
-                with mock.patch.object(
-                    cfg, "check_lock_info", return_value=(-1, "")
-                ):
+                with mock.patch.object(lock, "lock_data_file"):
                     fake_stdout = io.StringIO()
                     with contextlib.redirect_stdout(fake_stdout):
                         ret = action_disable(args_mock, cfg=cfg)
@@ -192,6 +199,8 @@ class TestDisable:
         assert expected == json.loads(fake_stdout.getvalue())
 
     @pytest.mark.parametrize("assume_yes", (True, False))
+    @mock.patch("uaclient.contract.UAContractClient.update_activity_token")
+    @mock.patch("uaclient.lock.check_lock_info", return_value=(-1, ""))
     @mock.patch("uaclient.entitlements.entitlement_factory")
     @mock.patch("uaclient.entitlements.valid_services")
     @mock.patch("uaclient.status.status")
@@ -200,6 +209,8 @@ class TestDisable:
         m_status,
         m_valid_services,
         m_entitlement_factory,
+        _m_check_lock_info,
+        _m_update_activity_token,
         assume_yes,
         tmpdir,
         event,
@@ -219,6 +230,7 @@ class TestDisable:
             ),
         )
         type(m_ent1_obj).name = mock.PropertyMock(return_value="ent1")
+        m_ent1_obj._check_for_reboot.return_value = False
 
         m_ent2_cls = mock.Mock()
         m_ent2_obj = m_ent2_cls.return_value
@@ -231,12 +243,14 @@ class TestDisable:
             ),
         )
         type(m_ent2_obj).name = mock.PropertyMock(return_value="ent2")
+        m_ent2_obj._check_for_reboot.return_value = False
 
         m_ent3_cls = mock.Mock()
         m_ent3_obj = m_ent3_cls.return_value
         m_ent3_obj.enabled_variant = None
         m_ent3_obj.disable.return_value = (True, None)
         type(m_ent3_obj).name = mock.PropertyMock(return_value="ent3")
+        m_ent3_obj._check_for_reboot.return_value = False
 
         def factory_side_effect(cfg, name):
             if name == "ent2":
@@ -254,10 +268,9 @@ class TestDisable:
         args_mock.assume_yes = assume_yes
         args_mock.purge = False
 
-        with pytest.raises(exceptions.UbuntuProError) as err:
-            with mock.patch.object(
-                cfg, "check_lock_info", return_value=(-1, "")
-            ):
+        first_fake_stdout = io.StringIO()
+        with contextlib.redirect_stdout(first_fake_stdout):
+            with mock.patch.object(lock, "lock_data_file"):
                 action_disable(args_mock, cfg=cfg)
 
         assert (
@@ -266,7 +279,7 @@ class TestDisable:
                 invalid_service="ent1",
                 service_msg="Try ent2, ent3.",
             ).msg
-            == err.value.msg
+            in first_fake_stdout.getvalue()
         )
 
         for m_ent_cls in [m_ent2_cls, m_ent3_cls]:
@@ -274,7 +287,7 @@ class TestDisable:
                 mock.call(cfg, assume_yes=assume_yes, purge=False)
             ] == m_ent_cls.call_args_list
 
-        expected_disable_call = mock.call()
+        expected_disable_call = mock.call(mock.ANY)
         for m_ent in [m_ent2_obj, m_ent3_obj]:
             assert [expected_disable_call] == m_ent.disable.call_args_list
 
@@ -284,19 +297,10 @@ class TestDisable:
         cfg = FakeConfig.for_attached_machine()
         args_mock.assume_yes = True
         args_mock.format = "json"
-        with pytest.raises(SystemExit):
-            with mock.patch.object(
-                event, "_event_logger_mode", event_logger.EventLoggerMode.JSON
-            ):
-                with mock.patch.object(event, "set_event_mode"):
-                    with mock.patch.object(
-                        cfg, "check_lock_info", return_value=(-1, "")
-                    ):
-                        fake_stdout = io.StringIO()
-                        with contextlib.redirect_stdout(fake_stdout):
-                            main_error_handler(action_disable)(
-                                args_mock, cfg=cfg
-                            )
+        with mock.patch.object(lock, "lock_data_file"):
+            fake_stdout = io.StringIO()
+            with contextlib.redirect_stdout(fake_stdout):
+                main_error_handler(action_disable)(args_mock, cfg=cfg)
 
         expected = {
             "_schema_version": event_logger.JSON_SCHEMA_VERSION,
@@ -334,14 +338,17 @@ class TestDisable:
     @pytest.mark.parametrize(
         "root,expected_error_template",
         [
-            (True, messages.E_INVALID_SERVICE_OP_FAILURE),
             (False, messages.E_NONROOT_USER),
         ],
     )
+    @mock.patch("uaclient.contract.UAContractClient.update_activity_token")
+    @mock.patch("uaclient.lock.check_lock_info", return_value=(-1, ""))
     @mock.patch("uaclient.util.we_are_currently_root")
     def test_invalid_service_error_message(
         self,
         m_we_are_currently_root,
+        _m_check_lock_info,
+        _m_update_activity_token,
         root,
         expected_error_template,
         FakeConfig,
@@ -354,25 +361,15 @@ class TestDisable:
         cfg = FakeConfig.for_attached_machine()
         args = mock.MagicMock()
         args.purge = False
+        args.service = ["esm-infra"]
 
-        if root:
-            expected_error = expected_error_template.format(
-                operation="disable",
-                invalid_service="bogus",
-                service_msg=all_service_msg,
-            )
-            expected_info = {
-                "operation": "disable",
-                "invalid_service": "bogus",
-                "service_msg": all_service_msg,
-            }
-        else:
-            expected_error = expected_error_template
-            expected_info = None
+        expected_error = expected_error_template
+        expected_info = None
 
         with pytest.raises(exceptions.UbuntuProError) as err:
-            args.service = ["bogus"]
-            action_disable(args, cfg)
+            with mock.patch.object(lock, "lock_data_file"):
+                action_disable(args, cfg)
+
         assert expected_error.msg == err.value.msg
 
         args.assume_yes = True
@@ -384,7 +381,8 @@ class TestDisable:
                 with mock.patch.object(event, "set_event_mode"):
                     fake_stdout = io.StringIO()
                     with contextlib.redirect_stdout(fake_stdout):
-                        main_error_handler(action_disable)(args, cfg)
+                        with mock.patch.object(lock, "lock_data_file"):
+                            main_error_handler(action_disable)(args, cfg)
 
         expected = {
             "_schema_version": event_logger.JSON_SCHEMA_VERSION,
@@ -407,8 +405,12 @@ class TestDisable:
         assert expected == json.loads(fake_stdout.getvalue())
 
     @pytest.mark.parametrize("service", [["bogus"], ["bogus1", "bogus2"]])
+    @mock.patch("uaclient.contract.UAContractClient.update_activity_token")
+    @mock.patch("uaclient.lock.check_lock_info", return_value=(-1, ""))
     def test_invalid_service_names(
         self,
+        _m_check_lock_info,
+        _m_update_activity_token,
         service,
         FakeConfig,
         event,
@@ -424,22 +426,20 @@ class TestDisable:
             invalid_service=", ".join(sorted(service)),
             service_msg=all_service_msg,
         )
-        with pytest.raises(exceptions.UbuntuProError) as err:
-            args.service = service
-            action_disable(args, cfg)
+        first_fake_stdout = io.StringIO()
+        with contextlib.redirect_stdout(first_fake_stdout):
+            with mock.patch.object(lock, "lock_data_file"):
+                args.service = service
+                action_disable(args, cfg)
 
-        assert expected_error.msg == err.value.msg
+        assert expected_error.msg in first_fake_stdout.getvalue()
 
         args.assume_yes = True
         args.format = "json"
-        with pytest.raises(SystemExit):
-            with mock.patch.object(
-                event, "_event_logger_mode", event_logger.EventLoggerMode.JSON
-            ):
-                with mock.patch.object(event, "set_event_mode"):
-                    fake_stdout = io.StringIO()
-                    with contextlib.redirect_stdout(fake_stdout):
-                        main_error_handler(action_disable)(args, cfg)
+        with mock.patch.object(lock, "lock_data_file"):
+            fake_stdout = io.StringIO()
+            with contextlib.redirect_stdout(fake_stdout):
+                main_error_handler(action_disable)(args, cfg)
 
         expected = {
             "_schema_version": event_logger.JSON_SCHEMA_VERSION,
@@ -488,9 +488,12 @@ class TestDisable:
         args.command = "disable"
         if root:
             expected_error = expected_error_template.format(
-                valid_service="esm-infra"
+                valid_service="esm-infra", operation="disable"
             )
-            expected_info = {"valid_service": "esm-infra"}
+            expected_info = {
+                "valid_service": "esm-infra",
+                "operation": "disable",
+            }
         else:
             expected_error = expected_error_template
             expected_info = None
@@ -532,12 +535,14 @@ class TestDisable:
             expected["errors"][0]["additional_info"] = expected_info
         assert expected == json.loads(fake_stdout.getvalue())
 
+    @mock.patch("uaclient.lock.check_lock_info")
     @mock.patch("time.sleep")
     @mock.patch("uaclient.system.subp")
     def test_lock_file_exists(
         self,
         m_subp,
         m_sleep,
+        m_check_lock_info,
         FakeConfig,
         event,
     ):
@@ -547,11 +552,11 @@ class TestDisable:
         expected_error = messages.E_LOCK_HELD_ERROR.format(
             lock_request="pro disable", lock_holder="pro enable", pid="123"
         )
-        cfg.write_cache("lock", "123:pro enable")
+        m_check_lock_info.return_value = (123, "pro enable")
         with pytest.raises(exceptions.LockHeldError) as err:
             args.service = ["esm-infra"]
             action_disable(args, cfg)
-        assert [mock.call(["ps", "123"])] * 12 == m_subp.call_args_list
+        assert 12 == m_check_lock_info.call_count
         assert expected_error.msg == err.value.msg
 
         args.assume_yes = True
@@ -621,17 +626,25 @@ class TestDisable:
         }
         assert expected == json.loads(fake_stdout.getvalue())
 
-    def test_purge_assume_yes_incompatible(self, capsys):
+    @mock.patch("uaclient.lock.check_lock_info", return_value=(-1, ""))
+    @mock.patch("uaclient.cli.cli_util._is_attached")
+    def test_purge_assume_yes_incompatible(
+        self, m_is_attached, _m_check_lock_info, capsys
+    ):
         cfg = mock.MagicMock()
         args_mock = mock.MagicMock()
         args_mock.service = "test"
         args_mock.assume_yes = True
         args_mock.purge = True
 
+        m_is_attached.return_value = mock.MagicMock(
+            is_attached=True,
+            contract_status="active",
+            contract_remaining_days=100,
+        )
+
         with pytest.raises(SystemExit):
-            with mock.patch.object(
-                cfg, "check_lock_info", return_value=(-1, "")
-            ):
+            with mock.patch.object(lock, "lock_data_file"):
                 main_error_handler(action_disable)(args_mock, cfg)
 
         _out, err = capsys.readouterr()
@@ -642,3 +655,160 @@ class TestDisable:
             ).msg
             in err.strip()
         )
+
+
+class TestPromptForDependencyHandling:
+    @pytest.mark.parametrize(
+        [
+            "service",
+            "all_dependencies",
+            "enabled_service_names",
+            "called_name",
+            "service_title",
+            "prompt_side_effects",
+            "expected_prompts",
+            "expected_raise",
+        ],
+        [
+            # no dependencies
+            (
+                "one",
+                [
+                    ServiceWithDependencies(
+                        name="two", incompatible_with=[], depends_on=[]
+                    )
+                ],
+                [],
+                "one",
+                "One",
+                [],
+                [],
+                does_not_raise(),
+            ),
+            # required by "two", but two not enabled
+            (
+                "one",
+                [
+                    ServiceWithDependencies(
+                        name="two",
+                        incompatible_with=[],
+                        depends_on=[
+                            ServiceWithReason(
+                                name="one", reason=mock.MagicMock()
+                            )
+                        ],
+                    )
+                ],
+                [],
+                "one",
+                "One",
+                [],
+                [],
+                does_not_raise(),
+            ),
+            # required by "two", two enabled, successful prompt
+            (
+                "one",
+                [
+                    ServiceWithDependencies(
+                        name="two",
+                        incompatible_with=[],
+                        depends_on=[
+                            ServiceWithReason(
+                                name="one", reason=mock.MagicMock()
+                            )
+                        ],
+                    )
+                ],
+                ["two"],
+                "one",
+                "One",
+                [True],
+                [mock.call(msg=mock.ANY)],
+                does_not_raise(),
+            ),
+            # required by "two", two enabled, denied prompt
+            (
+                "one",
+                [
+                    ServiceWithDependencies(
+                        name="two",
+                        incompatible_with=[],
+                        depends_on=[
+                            ServiceWithReason(
+                                name="one", reason=mock.MagicMock()
+                            )
+                        ],
+                    )
+                ],
+                ["two"],
+                "one",
+                "One",
+                [False],
+                [mock.call(msg=mock.ANY)],
+                pytest.raises(exceptions.DependentServiceStopsDisable),
+            ),
+            # required by "two" and "three", three enabled, success
+            (
+                "one",
+                [
+                    ServiceWithDependencies(
+                        name="two",
+                        incompatible_with=[],
+                        depends_on=[
+                            ServiceWithReason(
+                                name="one", reason=mock.MagicMock()
+                            )
+                        ],
+                    ),
+                    ServiceWithDependencies(
+                        name="three",
+                        incompatible_with=[],
+                        depends_on=[
+                            ServiceWithReason(
+                                name="one", reason=mock.MagicMock()
+                            )
+                        ],
+                    ),
+                ],
+                ["three"],
+                "one",
+                "One",
+                [True],
+                [mock.call(msg=mock.ANY)],
+                does_not_raise(),
+            ),
+        ],
+    )
+    @mock.patch("uaclient.entitlements.get_title")
+    @mock.patch("uaclient.util.prompt_for_confirmation")
+    def test_prompt_for_dependency_handling(
+        self,
+        m_prompt_for_confirmation,
+        m_entitlement_get_title,
+        service,
+        all_dependencies,
+        enabled_service_names,
+        called_name,
+        service_title,
+        prompt_side_effects,
+        expected_prompts,
+        expected_raise,
+        FakeConfig,
+    ):
+        m_entitlement_get_title.side_effect = (
+            lambda cfg, name, variant="": name.title()
+        )
+        m_prompt_for_confirmation.side_effect = prompt_side_effects
+
+        with expected_raise:
+            prompt_for_dependency_handling(
+                FakeConfig(),
+                service,
+                all_dependencies,
+                enabled_service_names,
+                called_name,
+                service_title,
+            )
+
+        assert expected_prompts == m_prompt_for_confirmation.call_args_list
