@@ -10,11 +10,12 @@ import textwrap
 import mock
 import pytest
 
-from uaclient import exceptions, messages, status, util
+from uaclient import exceptions, lock, messages, status, util
 from uaclient.cli import action_status, get_parser, main, status_parser
 from uaclient.conftest import FakeNotice
 from uaclient.event_logger import EventLoggerMode
 from uaclient.files.notices import Notice, NoticesManager
+from uaclient.files.user_config_file import UserConfigData
 from uaclient.yaml import safe_load
 
 M_PATH = "uaclient.cli."
@@ -341,11 +342,17 @@ Flags:
     "uaclient.status.get_contract_information",
     return_value=RESPONSE_CONTRACT_INFO,
 )
+@mock.patch(
+    "uaclient.files.user_config_file.UserConfigFileObject.public_config",
+    new_callable=mock.PropertyMock,
+    return_value=UserConfigData(),
+)
 class TestActionStatus:
-    @mock.patch(M_PATH + "setup_logging")
+    @mock.patch(M_PATH + "log.setup_cli_logging")
     def test_status_help(
         self,
         _m_setup_logging,
+        _m_public_config,
         _m_get_contract_information,
         _m_get_available_resources,
         _m_should_reboot,
@@ -372,8 +379,8 @@ class TestActionStatus:
             ([], ""),
             (
                 [
-                    [FakeNotice.a, "adesc"],
-                    [FakeNotice.b, "bdesc"],
+                    [FakeNotice.reboot_required, "adesc"],
+                    [FakeNotice.enable_reboot_required, "bdesc"],
                 ],
                 "\nNOTICES\nadesc\nbdesc\n",
             ),
@@ -389,10 +396,13 @@ class TestActionStatus:
             ),
         ),
     )
+    @mock.patch("uaclient.files.state_files.status_cache_file.write")
     @mock.patch("uaclient.status.format_expires", return_value="formatteddate")
     def test_attached(
         self,
         _m_format_expires,
+        _m_status_cache_file,
+        _m_public_config,
         _m_get_contract_information,
         _m_get_avail_resources,
         _m_should_reboot,
@@ -449,8 +459,11 @@ class TestActionStatus:
             (False),
         ),
     )
+    @mock.patch("uaclient.files.state_files.status_cache_file.write")
     def test_unattached(
         self,
+        _m_status_cache_file,
+        _m_public_config,
         _m_get_contract_information,
         _m_get_avail_resources,
         _m_should_reboot,
@@ -478,6 +491,7 @@ class TestActionStatus:
     )
     def test_simulated(
         self,
+        _m_public_config,
         _m_get_contract_information,
         _m_get_avail_resources,
         _m_should_reboot,
@@ -497,6 +511,8 @@ class TestActionStatus:
         )
         assert expected == capsys.readouterr()[0]
 
+    @mock.patch("uaclient.files.state_files.status_cache_file.write")
+    @mock.patch("uaclient.lock.check_lock_info")
     @mock.patch("uaclient.version.get_version", return_value="test_version")
     @mock.patch("uaclient.system.subp")
     @mock.patch(M_PATH + "time.sleep")
@@ -505,6 +521,9 @@ class TestActionStatus:
         m_sleep,
         _m_subp,
         _m_get_version,
+        m_check_lock_info,
+        _m_status_cache_file,
+        _m_public_config,
         _m_get_contract_information,
         _m_get_avail_resources,
         _m_should_reboot,
@@ -516,19 +535,20 @@ class TestActionStatus:
         """Check that --wait will will block and poll until lock released."""
         cfg = FakeConfig()
         mock_notice = NoticesManager()
-        lock_file = cfg.data_path("lock")
-        cfg.write_cache("lock", "123:pro auto-attach")
+        m_check_lock_info.return_value = (123, "pro disable")
 
         def fake_sleep(seconds):
             if m_sleep.call_count == 3:
-                os.unlink(lock_file)
+                m_check_lock_info.return_value = (-1, "")
                 mock_notice.remove(Notice.OPERATION_IN_PROGRESS)
 
         m_sleep.side_effect = fake_sleep
 
-        assert 0 == action_status(
-            mock.MagicMock(all=False, simulate_with_token=None), cfg=cfg
-        )
+        with mock.patch.object(lock, "lock_data_file"):
+            assert 0 == action_status(
+                mock.MagicMock(all=False, simulate_with_token=None), cfg=cfg
+            )
+
         assert [mock.call(1)] * 3 == m_sleep.call_args_list
         assert "...\n" + UNATTACHED_STATUS == capsys.readouterr()[0]
 
@@ -555,8 +575,11 @@ class TestActionStatus:
             },
         ),
     )
+    @mock.patch("uaclient.files.state_files.status_cache_file.write")
     def test_unattached_formats(
         self,
+        _m_status_cache_file,
+        _m_public_config,
         _m_get_contract_information,
         _m_get_avail_resources,
         _m_should_reboot,
@@ -665,8 +688,11 @@ class TestActionStatus:
         ),
     )
     @pytest.mark.parametrize("use_all", (True, False))
+    @mock.patch("uaclient.files.state_files.status_cache_file.write")
     def test_attached_formats(
         self,
+        _m_status_cache_file,
+        _m_public_config,
         _m_get_contract_information,
         _m_get_avail_resources,
         _m_should_reboot,
@@ -800,6 +826,7 @@ class TestActionStatus:
     @pytest.mark.parametrize("use_all", (True, False))
     def test_simulated_formats(
         self,
+        _m_public_config,
         _m_get_contract_information,
         _m_get_avail_resources,
         _m_should_reboot,
@@ -951,6 +978,7 @@ class TestActionStatus:
 
     def test_error_on_connectivity_errors(
         self,
+        _m_public_config,
         _m_get_contract_information,
         m_get_avail_resources,
         _m_should_reboot,
@@ -975,10 +1003,13 @@ class TestActionStatus:
         "encoding,expected_dash",
         (("utf-8", "\u2014"), ("UTF-8", "\u2014"), ("ascii", "-")),
     )
+    @mock.patch("uaclient.files.state_files.status_cache_file.write")
     @mock.patch("uaclient.status.format_expires", return_value="formatteddate")
     def test_unicode_dash_replacement_when_unprintable(
         self,
         _m_format_expires,
+        _m_status_cache_file,
+        _m_public_config,
         _m_get_contract_information,
         _m_get_avail_resources,
         _m_should_reboot,
@@ -1040,6 +1071,7 @@ class TestActionStatus:
     )
     def test_errors_are_raised_appropriately(
         self,
+        _m_public_config,
         m_get_contract_information,
         _m_get_avail_resources,
         _m_should_reboot,
@@ -1101,6 +1133,7 @@ class TestActionStatus:
     )
     def test_errors_for_token_dates(
         self,
+        _m_public_config,
         m_get_contract_information,
         _m_get_avail_resources,
         _m_should_reboot,
