@@ -13,8 +13,9 @@ import pytest
 try:
     from uaclient import event_logger
     from uaclient.config import UAConfig
+    from uaclient.entitlements.entitlement_status import ApplicationStatus
     from uaclient.files.notices import NoticeFileDetails
-    from uaclient.files.state_files import UserConfigData
+    from uaclient.files.user_config_file import UserConfigData
 except ImportError:
     raise
 
@@ -266,7 +267,6 @@ def FakeConfig(tmpdir):
 
             config = cls()
             config.machine_token_file._machine_token = machine_token
-            config.write_cache("status-cache", status_cache)
             return config
 
         def override_features(self, features_override):
@@ -285,9 +285,15 @@ def event():
 
 
 class FakeNotice(NoticeFileDetails, Enum):
-    a = NoticeFileDetails("01", "a", True, "notice_a")
-    a2 = NoticeFileDetails("03", "a2", True, "notice_a2")
-    b = NoticeFileDetails("02", "b2", False, "notice_b")
+    reboot_required = NoticeFileDetails(
+        "10", "reboot_required", False, "notice_a"
+    )
+    reboot_script_failed = NoticeFileDetails(
+        "12", "reboot_script_failed", True, "notice_a2"
+    )
+    enable_reboot_required = NoticeFileDetails(
+        "11", "enable_reboot_required", False, "notice_b"
+    )
 
 
 @pytest.yield_fixture(autouse=True)
@@ -303,3 +309,28 @@ def mock_notices_dir(tmpdir_factory):
             temp_dir.strpath,
         ):
             yield
+
+
+@pytest.fixture
+def mock_entitlement():
+    def factory_func(
+        *,
+        name="test",
+        title="test",
+        application_status=(ApplicationStatus.DISABLED, ""),
+        can_disable=(False, None),
+        disable=(False, None),
+        enable=(False, None)
+    ):
+        m_ent_cls = mock.MagicMock()
+        type(m_ent_cls).name = mock.PropertyMock(return_value=name)
+        m_ent_obj = m_ent_cls.return_value
+        type(m_ent_obj).title = mock.PropertyMock(return_value=title)
+        m_ent_obj.application_status.return_value = application_status
+        m_ent_obj.disable.return_value = disable
+        m_ent_obj.enable.return_value = enable
+        m_ent_obj.can_disable.return_value = can_disable
+
+        return (m_ent_cls, m_ent_obj)
+
+    return factory_func
