@@ -10,6 +10,7 @@ def machine_token(
     *,
     affordances: Dict[str, Any] = None,
     directives: Dict[str, Any] = None,
+    overrides: List[Dict[str, Any]] = None,
     entitled: bool = True,
     obligations: Dict[str, Any] = None,
     suites: List[str] = None,
@@ -30,6 +31,7 @@ def machine_token(
                         entitlement_type,
                         affordances=affordances,
                         directives=directives,
+                        overrides=overrides,
                         entitled=entitled,
                         obligations=obligations,
                         suites=suites,
@@ -46,6 +48,7 @@ def machine_access(
     *,
     affordances: Dict[str, Any] = None,
     directives: Dict[str, Any] = None,
+    overrides: List[Dict[str, Any]] = None,
     entitled: bool = True,
     obligations: Dict[str, Any] = None,
     suites: List[str] = None,
@@ -66,12 +69,16 @@ def machine_access(
 
         if additional_packages:
             directives["additionalPackages"] = additional_packages
+    if overrides is None:
+        overrides = []
+
     return {
         "obligations": obligations,
         "type": entitlement_type,
         "entitled": entitled,
         "directives": directives,
         "affordances": affordances,
+        "overrides": overrides,
     }
 
 
@@ -92,6 +99,7 @@ def entitlement_factory(tmpdir, FakeConfig):
         affordances: Dict[str, Any] = None,
         directives: Dict[str, Any] = None,
         obligations: Dict[str, Any] = None,
+        overrides: List[Dict[str, Any]] = None,
         entitled: bool = True,
         allow_beta: bool = False,
         called_name: str = "",
@@ -101,18 +109,26 @@ def entitlement_factory(tmpdir, FakeConfig):
         suites: List[str] = None,
         additional_packages: List[str] = None,
         cfg: Optional[config.UAConfig] = None,
-        cfg_extension: Optional[Dict[str, Any]] = None
+        cfg_extension: Optional[Dict[str, Any]] = None,
+        cfg_features: Optional[Dict[str, Any]] = None,
+        # Those extra args should be used for scenarios where a cls
+        # instance requires something that is not shared between all
+        # entitlement classes
+        extra_args: Optional[Dict[str, Any]] = None
     ):
         if not cfg:
             cfg_arg = {"data_dir": tmpdir.strpath}
             if cfg_extension is not None:
                 cfg_arg.update(cfg_extension)
+            if cfg_features is not None:
+                cfg_arg["features"] = cfg_features
             cfg = FakeConfig(cfg_overrides=cfg_arg)
             cfg.machine_token_file.write(
                 machine_token(
                     cls.name,
                     affordances=affordances,
                     directives=directives,
+                    overrides=overrides,
                     obligations=obligations,
                     entitled=entitled,
                     suites=suites,
@@ -124,9 +140,14 @@ def entitlement_factory(tmpdir, FakeConfig):
             "allow_beta": allow_beta,
             "called_name": called_name,
             "access_only": access_only,
+            "purge": purge,
         }
         if assume_yes is not None:
             args["assume_yes"] = assume_yes
+
+        if extra_args:
+            args = {**args, **extra_args}
+
         return cls(cfg, **args)
 
     return factory_func
