@@ -1,8 +1,6 @@
 """Tests related to uaclient.entitlement.base module."""
 
-import contextlib
 import copy
-import io
 import logging
 import os
 from functools import partial
@@ -25,6 +23,7 @@ from uaclient.entitlements.fips import (
     UBUNTU_FIPS_METAPACKAGE_DEPENDS_FOCAL,
     UBUNTU_FIPS_METAPACKAGE_DEPENDS_XENIAL,
     FIPSEntitlement,
+    FIPSPreviewEntitlement,
     FIPSUpdatesEntitlement,
 )
 from uaclient.files.notices import Notice, NoticesManager
@@ -109,6 +108,54 @@ class TestFIPSEntitlementDefaults:
         conditional_packages = entitlement.conditional_packages
         assert expected == conditional_packages
 
+    @pytest.mark.parametrize(
+        "fips_version, assume_yes, expected_continue",
+        (
+            (
+                "0",
+                True,
+                True,
+            ),
+            (
+                "0",
+                False,
+                False,
+            ),
+            (
+                "999",
+                True,
+                True,
+            ),
+            (
+                "999",
+                False,
+                True,
+            ),
+        ),
+    )
+    @mock.patch(M_PATH + "apt.get_pkg_candidate_version")
+    @mock.patch(M_PATH + "util.prompt_for_confirmation")
+    def test_kernel_downgrade(
+        self,
+        m_prompt_for_confirmation,
+        m_pkg_candidate_version,
+        fips_version,
+        assume_yes,
+        expected_continue,
+        entitlement,
+    ):
+        """Test kernel downgrades block install if user denies prompt"""
+        # if user is prompted for confirmation assume they say no
+        if not assume_yes:
+            m_prompt_for_confirmation.return_value = False
+        else:
+            m_prompt_for_confirmation.return_value = True
+        m_pkg_candidate_version.return_value = fips_version
+        install_continues = entitlement.prompt_if_kernel_downgrade(
+            assume_yes=assume_yes
+        )
+        assert install_continues == expected_continue
+
     def test_default_repo_key_file(self, entitlement):
         """GPG keyring file is the same for both FIPS and FIPS with Updates"""
         assert entitlement.repo_key_file == "ubuntu-pro-fips.gpg"
@@ -135,6 +182,14 @@ class TestFIPSEntitlementDefaults:
                         },
                     )
                 ],
+                "pre_install": [
+                    (
+                        entitlement.prompt_if_kernel_downgrade,
+                        {
+                            "assume_yes": assume_yes,
+                        },
+                    )
+                ],
                 "post_enable": None,
                 "pre_disable": [
                     (
@@ -158,6 +213,14 @@ class TestFIPSEntitlementDefaults:
                         },
                     )
                 ],
+                "pre_install": [
+                    (
+                        entitlement.prompt_if_kernel_downgrade,
+                        {
+                            "assume_yes": assume_yes,
+                        },
+                    )
+                ],
                 "post_enable": None,
                 "pre_disable": [
                     (
@@ -198,6 +261,14 @@ class TestFIPSEntitlementDefaults:
                         },
                     )
                 ],
+                "pre_install": [
+                    (
+                        entitlement.prompt_if_kernel_downgrade,
+                        {
+                            "assume_yes": False,
+                        },
+                    )
+                ],
                 "post_enable": [messages.FIPS_RUN_APT_UPGRADE],
                 "pre_disable": [
                     (
@@ -223,6 +294,14 @@ class TestFIPSEntitlementDefaults:
                         },
                     )
                 ],
+                "pre_install": [
+                    (
+                        entitlement.prompt_if_kernel_downgrade,
+                        {
+                            "assume_yes": False,
+                        },
+                    )
+                ],
                 "post_enable": [messages.FIPS_RUN_APT_UPGRADE],
                 "pre_disable": [
                     (
@@ -244,181 +323,7 @@ class TestFIPSEntitlementDefaults:
             assert False, "Unknown entitlement {}".format(entitlement.name)
 
 
-class TestFIPSEntitlementCanEnable:
-    @mock.patch("uaclient.util.is_config_value_true", return_value=False)
-    def test_can_enable_true_on_entitlement_inactive(
-        self, m_is_config_value_true, capsys, entitlement
-    ):
-        """When entitlement is disabled, can_enable returns True."""
-        with mock.patch.object(
-            entitlement,
-            "applicability_status",
-            return_value=(ApplicabilityStatus.APPLICABLE, ""),
-        ):
-            with mock.patch.object(
-                entitlement,
-                "application_status",
-                return_value=(ApplicationStatus.DISABLED, ""),
-            ):
-                with mock.patch.object(
-                    entitlement,
-                    "detect_incompatible_services",
-                    return_value=False,
-                ):
-                    assert (True, None) == entitlement.can_enable()
-        assert ("", "") == capsys.readouterr()
-
-
 class TestFIPSEntitlementEnable:
-    @mock.patch("uaclient.apt.update_sources_list")
-    @mock.patch("uaclient.apt.setup_apt_proxy")
-    @mock.patch(M_PATH + "get_cloud_type", return_value=("", None))
-    def test_enable_configures_apt_sources_and_auth_files(
-        self,
-        _m_get_cloud_type,
-        m_setup_apt_proxy,
-        m_update_sources_list,
-        entitlement,
-    ):
-        """When entitled, configure apt repo auth token, pinning and url."""
-        notice_ent_cls = NoticesManager()
-        patched_packages = ["a", "b"]
-        expected_conditional_packages = [
-            "openssh-server",
-            "openssh-server-hmac",
-            "strongswan",
-            "strongswan-hmac",
-        ]
-
-        with contextlib.ExitStack() as stack:
-            m_add_apt = stack.enter_context(
-                mock.patch("uaclient.apt.add_auth_apt_repo")
-            )
-            m_add_pinning = stack.enter_context(
-                mock.patch("uaclient.apt.add_ppa_pinning")
-            )
-            m_installed_pkgs = stack.enter_context(
-                mock.patch(
-                    "uaclient.apt.get_installed_packages_names",
-                    return_value=["openssh-server", "strongswan"],
-                )
-            )
-            m_subp = stack.enter_context(
-                mock.patch("uaclient.system.subp", return_value=("", ""))
-            )
-            m_can_enable = stack.enter_context(
-                mock.patch.object(entitlement, "can_enable")
-            )
-            stack.enter_context(
-                mock.patch("uaclient.util.handle_message_operations")
-            )
-            stack.enter_context(
-                mock.patch(
-                    "uaclient.system.get_release_info",
-                    return_value=mock.MagicMock(series="xenial"),
-                )
-            )
-            stack.enter_context(
-                mock.patch(
-                    "uaclient.entitlements.fips.system.should_reboot",
-                    return_value=True,
-                )
-            )
-            stack.enter_context(mock.patch(M_REPOPATH + "exists"))
-            stack.enter_context(
-                mock.patch.object(fips, "services_once_enabled_file")
-            )
-            # Note that this patch uses a PropertyMock and happens on the
-            # entitlement's type because packages is a property
-            m_packages = mock.PropertyMock(return_value=patched_packages)
-            stack.enter_context(
-                mock.patch.object(type(entitlement), "packages", m_packages)
-            )
-            stack.enter_context(
-                mock.patch("uaclient.system.is_container", return_value=False)
-            )
-
-            m_can_enable.return_value = (True, None)
-            assert (True, None) == entitlement.enable()
-
-        repo_url = "http://{}".format(entitlement.name.upper())
-        add_apt_calls = [
-            mock.call(
-                "/etc/apt/sources.list.d/ubuntu-{}.list".format(
-                    entitlement.name
-                ),
-                "{}/ubuntu".format(repo_url),
-                "{}-token".format(entitlement.name),
-                ["xenial"],
-                entitlement.repo_key_file,
-            )
-        ]
-        apt_pinning_calls = [
-            mock.call(
-                "/etc/apt/preferences.d/ubuntu-{}".format(entitlement.name),
-                repo_url,
-                entitlement.origin,
-                1001,
-            )
-        ]
-
-        install_cmd = []
-        install_cmd.append(
-            mock.call(
-                [
-                    "apt-get",
-                    "install",
-                    "--assume-yes",
-                    "--allow-downgrades",
-                    '-o Dpkg::Options::="--force-confdef"',
-                    '-o Dpkg::Options::="--force-confold"',
-                ]
-                + patched_packages,
-                capture=True,
-                retry_sleeps=apt.APT_RETRIES,
-                override_env_vars={"DEBIAN_FRONTEND": "noninteractive"},
-            )
-        )
-
-        for pkg in expected_conditional_packages:
-            install_cmd.append(
-                mock.call(
-                    [
-                        "apt-get",
-                        "install",
-                        "--assume-yes",
-                        "--allow-downgrades",
-                        '-o Dpkg::Options::="--force-confdef"',
-                        '-o Dpkg::Options::="--force-confold"',
-                        pkg,
-                    ],
-                    capture=True,
-                    retry_sleeps=apt.APT_RETRIES,
-                    override_env_vars={"DEBIAN_FRONTEND": "noninteractive"},
-                )
-            )
-
-        subp_calls = [
-            mock.call(
-                ["apt-mark", "showholds"],
-                capture=True,
-                retry_sleeps=apt.APT_RETRIES,
-                override_env_vars=None,
-            ),
-        ]
-        subp_calls += install_cmd
-
-        assert [mock.call()] == m_can_enable.call_args_list
-        assert 1 == m_setup_apt_proxy.call_count
-        assert 1 == m_installed_pkgs.call_count
-        assert add_apt_calls == m_add_apt.call_args_list
-        assert apt_pinning_calls == m_add_pinning.call_args_list
-        assert subp_calls == m_subp.call_args_list
-        assert 2 == m_update_sources_list.call_count
-        assert [
-            messages.FIPS_SYSTEM_REBOOT_REQUIRED,
-        ] == notice_ent_cls.list()
-
     @pytest.mark.parametrize(
         "fips_common_enable_return_value, expected_remove_notice_calls",
         [
@@ -442,7 +347,7 @@ class TestFIPSEntitlementEnable:
         fips_entitlement = entitlement_factory(FIPSEntitlement)
         assert (
             fips_common_enable_return_value
-            is fips_entitlement._perform_enable()
+            is fips_entitlement._perform_enable(mock.MagicMock())
         )
         assert expected_remove_notice_calls == m_remove_notice.call_args_list
 
@@ -475,130 +380,13 @@ class TestFIPSEntitlementEnable:
     ):
         m_repo_enable.return_value = repo_enable_return_value
         with mock.patch.object(fips, "services_once_enabled_file"):
-            assert repo_enable_return_value is entitlement._perform_enable()
+            assert repo_enable_return_value is entitlement._perform_enable(
+                mock.MagicMock()
+            )
         assert (
             expected_remove_notice_calls == m_remove_notice.call_args_list[:2]
         )
 
-    @mock.patch("uaclient.apt.setup_apt_proxy")
-    @mock.patch("uaclient.apt.add_auth_apt_repo")
-    @mock.patch(
-        "uaclient.system.get_release_info",
-        return_value=mock.MagicMock(series="xenial"),
-    )
-    def test_enable_returns_false_on_missing_suites_directive(
-        self,
-        m_get_release_info,
-        m_add_apt,
-        _m_setup_apt_proxy,
-        fips_entitlement_factory,
-    ):
-        """When directives do not contain suites returns false."""
-        entitlement = fips_entitlement_factory(suites=[])
-
-        with mock.patch.object(
-            entitlement, "can_enable", return_value=(True, None)
-        ):
-            with mock.patch("uaclient.util.handle_message_operations"):
-                with pytest.raises(exceptions.UbuntuProError) as excinfo:
-                    entitlement.enable()
-        error_msg = (
-            "Ubuntu Pro server provided no suites directive for {}".format(
-                entitlement.name
-            )
-        )
-        assert error_msg == excinfo.value.msg
-        assert 0 == m_add_apt.call_count
-
-    @mock.patch("uaclient.apt.setup_apt_proxy")
-    def test_enable_errors_on_repo_pin_but_invalid_origin(
-        self, _m_setup_apt_proxy, entitlement
-    ):
-        """Error when no valid origin is provided on a pinned entitlemnt."""
-        entitlement.origin = None  # invalid value
-
-        with contextlib.ExitStack() as stack:
-            m_add_apt = stack.enter_context(
-                mock.patch("uaclient.apt.add_auth_apt_repo")
-            )
-            m_add_pinning = stack.enter_context(
-                mock.patch("uaclient.apt.add_ppa_pinning")
-            )
-            stack.enter_context(
-                mock.patch.object(
-                    entitlement, "can_enable", return_value=(True, None)
-                )
-            )
-            stack.enter_context(
-                mock.patch("uaclient.util.handle_message_operations")
-            )
-            m_remove_apt_config = stack.enter_context(
-                mock.patch.object(entitlement, "remove_apt_config")
-            )
-            stack.enter_context(
-                mock.patch(
-                    "uaclient.system.get_release_info",
-                    return_value=mock.MagicMock(series="xenial"),
-                )
-            )
-            stack.enter_context(mock.patch(M_REPOPATH + "exists"))
-
-            with pytest.raises(exceptions.UbuntuProError) as excinfo:
-                entitlement.enable()
-
-        error_msg = (
-            "Cannot setup apt pin. Empty apt repo origin value for {}\n"
-            "Could not enable {}."
-        ).format(
-            entitlement.name,
-            entitlement.title,
-        )
-        assert error_msg == excinfo.value.msg
-        assert 0 == m_add_apt.call_count
-        assert 0 == m_add_pinning.call_count
-        assert 0 == m_remove_apt_config.call_count
-
-    @mock.patch(
-        "uaclient.entitlements.fips.get_cloud_type", return_value=("", None)
-    )
-    @mock.patch("uaclient.system.get_release_info")
-    @mock.patch("uaclient.util.is_config_value_true", return_value=False)
-    @mock.patch("uaclient.util.prompt_for_confirmation", return_value=False)
-    @mock.patch("uaclient.util.handle_message_operations")
-    @mock.patch("uaclient.system.is_container", return_value=False)
-    def test_fips_enable_fails_when_livepatch_service_is_enabled(
-        self,
-        m_is_container,
-        m_handle_message_op,
-        m_prompt,
-        m_is_config_value_true,
-        m_get_release_info,
-        m_get_cloud_type,
-        entitlement_factory,
-    ):
-        fips_ent = entitlement_factory(FIPSEntitlement)
-        m_handle_message_op.return_value = True
-        base_path = "uaclient.entitlements.livepatch.LivepatchEntitlement"
-        m_get_release_info.return_value = mock.MagicMock(series="test")
-
-        with mock.patch(
-            "{}.application_status".format(base_path)
-        ) as m_livepatch:
-            with mock.patch.object(
-                fips_ent,
-                "applicability_status",
-                return_value=(ApplicabilityStatus.APPLICABLE, ""),
-            ):
-                m_livepatch.return_value = (
-                    ApplicationStatus.ENABLED,
-                    "",
-                )
-                ret, fail = fips_ent.enable()
-
-        assert not ret
-        expected_msg = "Cannot enable FIPS when Livepatch is enabled."
-        assert expected_msg == fail.message.msg
-
     @mock.patch("uaclient.util.handle_message_operations")
     @mock.patch(
         M_LIVEPATCH_PATH + "application_status",
@@ -627,7 +415,7 @@ class TestFIPSEntitlementEnable:
                     ApplicationStatus.ENABLED,
                     "",
                 )
-                result, reason = fips_entitlement.enable()
+                result, reason = fips_entitlement.enable(mock.MagicMock())
                 assert not result
                 expected_msg = (
                     "Cannot enable FIPS when FIPS Updates is enabled."
@@ -661,7 +449,7 @@ class TestFIPSEntitlementEnable:
             with mock.patch.object(
                 fips, "services_once_enabled_file", fake_dof
             ):
-                result, reason = fips_entitlement.enable()
+                result, reason = fips_entitlement.enable(mock.MagicMock())
                 assert not result
                 expected_msg = (
                     "Cannot enable FIPS because FIPS Updates was once enabled."
@@ -689,7 +477,7 @@ class TestFIPSEntitlementEnable:
             "{}.application_status".format(base_path)
         ) as m_livepatch:
             m_livepatch.return_value = (ApplicationStatus.DISABLED, "")
-            result, reason = entitlement.enable()
+            result, reason = entitlement.enable(mock.MagicMock())
             assert not result
             expected_msg = """\
             Ubuntu Xenial does not provide a GCP optimized FIPS kernel"""
@@ -726,7 +514,7 @@ class TestFIPSEntitlementEnable:
                 ApplicationStatus.DISABLED,
                 "",
             )
-            result, reason = entitlement.enable()
+            result, reason = entitlement.enable(mock.MagicMock())
             assert not result
             expected_msg = """\
             Ubuntu Test does not provide a GCP optimized FIPS kernel"""
@@ -824,7 +612,7 @@ class TestFIPSEntitlementEnable:
             NoCloudTypeReason.CLOUD_ID_ERROR,
         )
         fips_entitlement = entitlement_factory(FIPSEntitlement)
-        fips_entitlement._perform_enable()
+        fips_entitlement._perform_enable(mock.MagicMock())
         logs = caplog_text()
         assert (
             "Could not determine cloud, defaulting to generic FIPS package."
@@ -895,38 +683,28 @@ class TestFIPSEntitlementRemovePackages:
         assert exc_info.value.msg.strip() == expected_msg
 
 
-@mock.patch("uaclient.util.handle_message_operations", return_value=True)
-@mock.patch("uaclient.system.should_reboot", return_value=True)
-@mock.patch(
-    "uaclient.system.get_release_info",
-    return_value=mock.MagicMock(series="xenial"),
-)
-class TestFIPSEntitlementDisable:
-    def test_disable_on_can_disable_true_removes_apt_config_and_packages(
+class TestFIPSCheckForRebootMsg:
+    @pytest.mark.parametrize(
+        "operation,expected",
+        (
+            (
+                "disable operation",
+                messages.FIPS_DISABLE_REBOOT_REQUIRED,
+            ),
+        ),
+    )
+    @mock.patch("uaclient.system.should_reboot", return_value=True)
+    def test_check_for_reboot_message(
         self,
-        _m_get_release_info,
         _m_should_reboot,
-        m_handle_message_operations,
+        operation,
+        expected,
         entitlement,
     ):
         """When can_disable, disable removes apt config and packages."""
         notice_ent_cls = NoticesManager()
-
-        with mock.patch.object(
-            entitlement, "can_disable", return_value=(True, None)
-        ):
-            with mock.patch.object(
-                entitlement, "remove_apt_config"
-            ) as m_remove_apt_config:
-                with mock.patch.object(
-                    entitlement, "remove_packages"
-                ) as m_remove_packages:
-                    assert entitlement.disable(True)
-        assert [mock.call(silent=True)] == m_remove_apt_config.call_args_list
-        assert [mock.call()] == m_remove_packages.call_args_list
-        assert [
-            messages.FIPS_DISABLE_REBOOT_REQUIRED,
-        ] == notice_ent_cls.list()
+        entitlement._check_for_reboot_msg(operation=operation)
+        assert [expected] == notice_ent_cls.list()
 
 
 @mock.patch("uaclient.system.should_reboot")
@@ -935,8 +713,15 @@ class TestFIPSEntitlementApplicationStatus:
         "super_application_status",
         [s for s in ApplicationStatus if s is not ApplicationStatus.ENABLED],
     )
+    @mock.patch("uaclient.system.is_container", return_value=False)
+    @mock.patch("os.path.exists", return_value=False)
     def test_non_enabled_passed_through(
-        self, _m_should_reboot, entitlement, super_application_status
+        self,
+        _m_path_exists,
+        _m_is_container,
+        _m_should_reboot,
+        entitlement,
+        super_application_status,
     ):
         msg = "sure is some status here"
         with mock.patch(
@@ -951,8 +736,15 @@ class TestFIPSEntitlementApplicationStatus:
         "super_application_status",
         [s for s in ApplicationStatus if s is not ApplicationStatus.ENABLED],
     )
+    @mock.patch("uaclient.system.is_container", return_value=False)
+    @mock.patch("os.path.exists", return_value=False)
     def test_non_root_does_not_fail(
-        self, _m_should_reboot, super_application_status, FakeConfig
+        self,
+        _m_path_exists,
+        _m_is_container,
+        _m_should_reboot,
+        super_application_status,
+        FakeConfig,
     ):
         cfg = FakeConfig()
         entitlement = FIPSUpdatesEntitlement(cfg)
@@ -968,8 +760,10 @@ class TestFIPSEntitlementApplicationStatus:
     @pytest.mark.parametrize("should_reboot", ((True), (False)))
     @pytest.mark.parametrize("path_exists", ((True), (False)))
     @pytest.mark.parametrize("proc_content", (("0"), ("1")))
+    @mock.patch("uaclient.system.is_container", return_value=False)
     def test_proc_file_is_used_to_determine_application_status_message(
         self,
+        _m_is_container,
         m_should_reboot,
         proc_content,
         path_exists,
@@ -1066,6 +860,35 @@ class TestFIPSEntitlementApplicationStatus:
         assert expected_msg.msg == actual_msg.msg
         assert expected_msg.name == actual_msg.name
 
+    @mock.patch("uaclient.system.is_container", return_value=True)
+    def test_application_status_inside_container(
+        self,
+        _m_is_container,
+        m_should_reboot,
+        entitlement,
+    ):
+        m_should_reboot.return_value = False
+        notice_ent_cls = NoticesManager()
+        notice_ent_cls.add(
+            Notice.FIPS_SYSTEM_REBOOT_REQUIRED,
+            messages.FIPS_SYSTEM_REBOOT_REQUIRED,
+        )
+        expected_status = ApplicationStatus.ENABLED
+        expected_msg = "test"
+
+        with mock.patch(
+            M_PATH + "repo.RepoEntitlement.application_status",
+            return_value=(
+                expected_status,
+                messages.NamedMessage("test", expected_msg),
+            ),
+        ):
+            actual_status, actual_message = entitlement.application_status()
+
+        assert expected_status == actual_status
+        assert expected_msg == actual_message.msg
+        assert [] == notice_ent_cls.list()
+
     def test_fips_does_not_show_enabled_when_fips_updates_is(
         self, _m_should_reboot, entitlement
     ):
@@ -1093,7 +916,7 @@ class TestFipsEntitlementInstallPackages:
         m_run_apt.side_effect = fakes.FakeUbuntuProError()
         with mock.patch.object(entitlement, "remove_apt_config"):
             with pytest.raises(exceptions.UbuntuProError):
-                entitlement.install_packages()
+                entitlement.install_packages(mock.MagicMock())
 
     @mock.patch(M_PATH + "apt.get_installed_packages_names")
     @mock.patch(M_PATH + "apt.run_apt_install_command")
@@ -1104,7 +927,6 @@ class TestFipsEntitlementInstallPackages:
         fips_entitlement_factory,
         event,
     ):
-
         conditional_pkgs = ["b", "c"]
         m_installed_pkgs.return_value = conditional_pkgs
         packages = ["a"]
@@ -1116,12 +938,11 @@ class TestFipsEntitlementInstallPackages:
             fakes.FakeUbuntuProError(),
         ]
 
-        fake_stdout = io.StringIO()
-        with contextlib.redirect_stdout(fake_stdout):
-            with mock.patch.object(
-                type(entitlement), "conditional_packages", conditional_pkgs
-            ):
-                entitlement.install_packages()
+        progress_mock = mock.MagicMock()
+        with mock.patch.object(
+            type(entitlement), "conditional_packages", conditional_pkgs
+        ):
+            entitlement.install_packages(progress_mock)
 
         install_cmds = []
         all_pkgs = packages + conditional_pkgs
@@ -1138,23 +959,27 @@ class TestFipsEntitlementInstallPackages:
                 )
             )
 
-        expected_msg = "\n".join(
-            [
-                "Installing {} packages".format(entitlement.title),
-                "Updating standard Ubuntu package lists",
-                "Could not enable {}.".format(entitlement.title),
+        assert [
+            mock.call("message_operation", mock.ANY),
+            mock.call("info", "Updating standard Ubuntu package lists"),
+            mock.call(
+                "info",
                 messages.FIPS_PACKAGE_NOT_AVAILABLE.format(
                     service=entitlement.title, pkg="b"
                 ),
-                "Could not enable {}.".format(entitlement.title),
+            ),
+            mock.call(
+                "info",
                 messages.FIPS_PACKAGE_NOT_AVAILABLE.format(
                     service=entitlement.title, pkg="c"
                 ),
-            ]
-        )
+            ),
+        ] == progress_mock.emit.call_args_list
+        assert [
+            mock.call("Installing {} packages".format(entitlement.title)),
+        ] == progress_mock.progress.call_args_list
 
         assert install_cmds == m_run_apt_install.call_args_list
-        assert expected_msg.strip() in fake_stdout.getvalue().strip()
 
 
 class TestFipsSetupAPTConfig:
@@ -1185,7 +1010,7 @@ class TestFipsSetupAPTConfig:
     ):
         """Unmark only fips-specific package holds if present."""
         run_apt_command.return_value = held_packages
-        entitlement.setup_apt_config(silent=False)
+        entitlement.setup_apt_config(mock.MagicMock())
         expected_calls = [
             mock.call(
                 ["apt-mark", "showholds"],
@@ -1205,7 +1030,7 @@ class TestFipsSetupAPTConfig:
                 )
             )
         assert expected_calls == run_apt_command.call_args_list
-        assert [mock.call(silent=False)] == setup_apt_config.call_args_list
+        assert [mock.call(mock.ANY)] == setup_apt_config.call_args_list
 
 
 class TestFipsEntitlementPackages:
@@ -1220,6 +1045,12 @@ class TestFipsEntitlementPackages:
 
         assert isinstance(entitlement.packages, list)
 
+    @mock.patch("uaclient.system.is_container", return_value=True)
+    def test_packages_is_empty_if_running_on_container(
+        self, _m_is_container, entitlement
+    ):
+        assert [] == entitlement.packages
+
     @mock.patch(M_PATH + "apt.get_installed_packages_names", return_value=[])
     @mock.patch("uaclient.system.get_release_info")
     def test_fips_required_packages_included(
@@ -1291,7 +1122,10 @@ class TestFIPSUpdatesEntitlementEnable:
             fips_updates_ent = entitlement_factory(
                 FIPSUpdatesEntitlement, cfg=cfg
             )
-            assert fips_updates_ent._perform_enable() == enable_ret
+            assert (
+                fips_updates_ent._perform_enable(mock.MagicMock())
+                == enable_ret
+            )
 
         if enable_ret:
             assert 1 == m_services_once_enabled.write.call_count
@@ -1299,13 +1133,20 @@ class TestFIPSUpdatesEntitlementEnable:
             assert not m_services_once_enabled.write.call_count
 
 
-class TestFIPSUpdatesEntitlementCanEnable:
+class TestFIPSEntitlementCanEnable:
+    @pytest.mark.parametrize(
+        "fips_cls",
+        (
+            (FIPSUpdatesEntitlement),
+            (FIPSPreviewEntitlement),
+        ),
+    )
     @mock.patch("uaclient.util.is_config_value_true", return_value=False)
     def test_can_enable_false_if_fips_enabled(
-        self, m_is_config_value_true, capsys, entitlement_factory
+        self, m_is_config_value_true, fips_cls, capsys, entitlement_factory
     ):
         """When entitlement is disabled, can_enable returns True."""
-        entitlement = entitlement_factory(FIPSUpdatesEntitlement)
+        entitlement = entitlement_factory(fips_cls)
         with mock.patch.object(
             entitlement,
             "applicability_status",
@@ -1329,3 +1170,11 @@ class TestFIPSUpdatesEntitlementCanEnable:
                         reason.reason
                         == CanEnableFailureReason.INCOMPATIBLE_SERVICE
                     )
+
+
+class TestFipsPreview:
+    def test_allow_fips_on_cloud_is_always_true(self, entitlement_factory):
+        entitlement = entitlement_factory(FIPSPreviewEntitlement)
+        assert entitlement._allow_fips_on_cloud_instance(
+            series="test", cloud_id="test"
+        )
