@@ -1,5 +1,3 @@
-import copy
-
 import mock
 import pytest
 
@@ -7,10 +5,9 @@ from uaclient import apt, exceptions, messages, util
 from uaclient.entitlements.entitlement_status import (
     ApplicabilityStatus,
     ApplicationStatus,
-    UserFacingStatus,
 )
 from uaclient.entitlements.repo import RepoEntitlement
-from uaclient.entitlements.tests.conftest import machine_token
+from uaclient.testing.helpers import does_not_raise
 
 M_PATH = "uaclient.entitlements.repo."
 M_CONTRACT_PATH = "uaclient.entitlements.repo.contract.UAContractClient."
@@ -29,6 +26,11 @@ class RepoTestEntitlementRepoWithPin(RepoTestEntitlement):
     repo_pin_priority = 1000
 
 
+class RepoTestEntitlementRepoWithRemovePackages(RepoTestEntitlement):
+    def remove_packages(self):
+        pass
+
+
 @pytest.fixture
 def entitlement(entitlement_factory):
     return entitlement_factory(
@@ -36,41 +38,6 @@ def entitlement(entitlement_factory):
     )
 
 
-class TestUserFacingStatus:
-    @mock.patch(M_PATH + "system.get_release_info")
-    def test_inapplicable_on_inapplicable_applicability_status(
-        self, m_release_info, entitlement
-    ):
-        """When applicability_status is INAPPLICABLE, return INAPPLICABLE."""
-        m_release_info.return_value = mock.MagicMock(
-            series="example", pretty_version="version"
-        )
-        applicability, details = entitlement.applicability_status()
-        assert ApplicabilityStatus.INAPPLICABLE == applicability
-        expected_details = (
-            "Repo Test Class is not available for Ubuntu version."
-        )
-        assert expected_details == details.msg
-        uf_status, _ = entitlement.user_facing_status()
-        assert UserFacingStatus.INAPPLICABLE == uf_status
-
-    @mock.patch(M_PATH + "system.get_release_info")
-    def test_unavailable_on_unentitled(self, m_release_info, entitlement):
-        """When unentitled, return UNAVAILABLE."""
-        no_entitlements = copy.deepcopy(machine_token("blah"))
-        # delete all enttlements
-        no_entitlements["machineTokenInfo"]["contractInfo"][
-            "resourceEntitlements"
-        ].pop()
-        entitlement.cfg.machine_token_file.write(no_entitlements)
-        m_release_info.return_value = mock.MagicMock(series="xenial")
-        applicability, _details = entitlement.applicability_status()
-        assert ApplicabilityStatus.APPLICABLE == applicability
-        uf_status, uf_details = entitlement.user_facing_status()
-        assert UserFacingStatus.UNAVAILABLE == uf_status
-        assert "Repo Test Class is not entitled" == uf_details.msg
-
-
 class TestProcessContractDeltas:
     @pytest.mark.parametrize("orig_access", ({}, {"entitlement": {}}))
     def test_on_no_deltas(self, orig_access):
@@ -88,7 +55,9 @@ class TestProcessContractDeltas:
 
     @pytest.mark.parametrize("entitled", (False, util.DROPPED_KEY))
     @mock.patch.object(RepoTestEntitlement, "disable")
-    @mock.patch.object(RepoTestEntitlement, "can_disable", return_value=True)
+    @mock.patch.object(
+        RepoTestEntitlement, "can_disable", return_value=(True, None)
+    )
     @mock.patch.object(RepoTestEntitlement, "application_status")
     def test_disable_when_delta_to_unentitled(
         self,
@@ -105,7 +74,7 @@ class TestProcessContractDeltas:
             {"entitlement": {"entitled": True}},
             {"entitlement": {"entitled": entitled}},
         )
-        assert [mock.call()] == m_disable.call_args_list
+        assert [mock.call(mock.ANY)] == m_disable.call_args_list
 
     @mock.patch.object(RepoTestEntitlement, "remove_apt_config")
     @mock.patch.object(RepoTestEntitlement, "application_status")
@@ -162,7 +131,7 @@ class TestProcessContractDeltas:
             },
             allow_enable=True,
         )
-        assert [mock.call()] == m_enable.call_args_list
+        assert [mock.call(mock.ANY)] == m_enable.call_args_list
 
     @mock.patch.object(RepoTestEntitlement, "enable")
     @mock.patch.object(RepoTestEntitlement, "application_status")
@@ -200,6 +169,9 @@ class TestProcessContractDeltas:
         assert expected_msg in capsys.readouterr()[1]
 
     @pytest.mark.parametrize("packages", ([], ["extremetuxracer"]))
+    @mock.patch(
+        "uaclient.files.state_files.status_cache_file.read", return_value=None
+    )
     @mock.patch.object(RepoTestEntitlement, "install_packages")
     @mock.patch(M_PATH + "apt.remove_auth_apt_repo")
     @mock.patch.object(RepoTestEntitlement, "setup_apt_config")
@@ -214,6 +186,7 @@ class TestProcessContractDeltas:
         m_setup_apt_config,
         m_remove_auth_apt_repo,
         m_install_packages,
+        _m_status_cache,
         packages,
         entitlement,
     ):
@@ -233,11 +206,11 @@ class TestProcessContractDeltas:
         assert entitlement.process_contract_deltas(
             {"entitlement": {"entitled": True}}, deltas
         )
-        assert [mock.call()] == m_remove_apt_config.call_args_list
-        assert [mock.call()] == m_setup_apt_config.call_args_list
+        assert [mock.call(mock.ANY)] == m_remove_apt_config.call_args_list
+        assert [mock.call(mock.ANY)] == m_setup_apt_config.call_args_list
         if packages:
             assert [
-                mock.call(package_list=packages)
+                mock.call(mock.ANY, package_list=packages)
             ] == m_install_packages.call_args_list
         else:
             assert 0 == m_install_packages.call_count
@@ -247,10 +220,10 @@ class TestProcessContractDeltas:
     @pytest.mark.parametrize(
         "series,file_extension", (("jammy", "list"), ("noble", "sources"))
     )
+    @mock.patch("uaclient.files.state_files.status_cache_file.read")
     @mock.patch(
         "uaclient.entitlements.base.UAEntitlement.process_contract_deltas"
     )
-    @mock.patch("uaclient.config.UAConfig.read_cache")
     @mock.patch(M_PATH + "system.get_release_info")
     @mock.patch(M_PATH + "apt.remove_auth_apt_repo")
     @mock.patch.object(RepoTestEntitlement, "setup_apt_config")
@@ -263,8 +236,8 @@ class TestProcessContractDeltas:
         m_setup_apt_config,
         m_remove_auth_apt_repo,
         m_release_info,
-        m_read_cache,
         m_process_contract_deltas,
+        m_status_cache_read,
         series,
         file_extension,
         entitlement,
@@ -272,7 +245,7 @@ class TestProcessContractDeltas:
         """Remove old apt url when aptURL delta occurs on active service."""
         m_check_apt_url_applied.return_value = False
         m_process_contract_deltas.return_value = False
-        m_read_cache.return_value = {
+        m_status_cache_read.return_value = {
             "services": [{"name": "repotest", "status": "enabled"}]
         }
         m_release_info.return_value.series = series
@@ -291,8 +264,8 @@ class TestProcessContractDeltas:
                 "resourceToken": "repotest-token",
             },
         )
-        assert [mock.call()] == m_remove_apt_config.call_args_list
-        assert [mock.call()] == m_setup_apt_config.call_args_list
+        assert [mock.call(mock.ANY)] == m_remove_apt_config.call_args_list
+        assert [mock.call(mock.ANY)] == m_setup_apt_config.call_args_list
         apt_auth_remove_calls = [
             mock.call(
                 "/etc/apt/sources.list.d/ubuntu-repotest.{}".format(
@@ -303,9 +276,9 @@ class TestProcessContractDeltas:
         ]
         assert apt_auth_remove_calls == m_remove_auth_apt_repo.call_args_list
         assert [
-            mock.call("status-cache"),
-            mock.call("status-cache"),
-        ] == m_read_cache.call_args_list
+            mock.call(),
+            mock.call(),
+        ] == m_status_cache_read.call_args_list
         assert 1 == m_process_contract_deltas.call_count
 
         assert [
@@ -316,7 +289,7 @@ class TestProcessContractDeltas:
     @mock.patch(
         "uaclient.entitlements.base.UAEntitlement.process_contract_deltas"
     )
-    @mock.patch("uaclient.config.UAConfig.read_cache")
+    @mock.patch("uaclient.files.state_files.status_cache_file.read")
     @mock.patch(M_PATH + "system.get_release_info")
     @mock.patch(M_PATH + "apt.remove_auth_apt_repo")
     @mock.patch.object(RepoTestEntitlement, "setup_apt_config")
@@ -329,14 +302,14 @@ class TestProcessContractDeltas:
         m_setup_apt_config,
         m_remove_auth_apt_repo,
         m_release_info,
-        m_read_cache,
+        m_status_cache_read,
         m_process_contract_deltas,
         entitlement,
     ):
         """Do not change system if apt url delta is already applied."""
         m_check_apt_url_applied.return_value = True
         m_process_contract_deltas.return_value = False
-        m_read_cache.return_value = {
+        m_status_cache_read.return_value = {
             "services": [{"name": "repotest", "status": "enabled"}]
         }
         assert entitlement.process_contract_deltas(
@@ -359,9 +332,9 @@ class TestProcessContractDeltas:
         assert m_remove_auth_apt_repo.call_count == 0
 
         assert [
-            mock.call("status-cache"),
-            mock.call("status-cache"),
-        ] == m_read_cache.call_args_list
+            mock.call(),
+            mock.call(),
+        ] == m_status_cache_read.call_args_list
         assert 1 == m_process_contract_deltas.call_count
 
         assert [
@@ -371,63 +344,6 @@ class TestProcessContractDeltas:
 
 
 class TestRepoEnable:
-    @pytest.mark.parametrize(
-        "pre_disable_msg,post_disable_msg,output,retval",
-        (
-            (
-                ["pre1", (lambda: False, {}), "pre2"],
-                ["post1"],
-                "pre1\n",
-                False,
-            ),
-            (["pre1", (lambda: True, {}), "pre2"], [], "pre1\npre2\n", True),
-            (
-                ["pre1", (lambda: True, {}), "pre2"],
-                ["post1", (lambda: False, {}), "post2"],
-                "pre1\npre2\npost1\n",
-                False,
-            ),
-            (
-                ["pre1", (lambda: True, {}), "pre2"],
-                ["post1", (lambda: True, {}), "post2"],
-                "pre1\npre2\npost1\npost2\n",
-                True,
-            ),
-        ),
-    )
-    @mock.patch(M_PATH + "system.subp", return_value=("", ""))
-    @mock.patch(M_PATH + "system.should_reboot")
-    @mock.patch.object(RepoTestEntitlement, "remove_apt_config")
-    @mock.patch.object(
-        RepoTestEntitlement, "can_disable", return_value=(True, None)
-    )
-    def test_enable_can_exit_on_pre_or_post_disable_messaging_hooks(
-        self,
-        _can_disable,
-        remove_apt_config,
-        m_should_reboot,
-        m_subp,
-        pre_disable_msg,
-        post_disable_msg,
-        output,
-        retval,
-        entitlement,
-        capsys,
-        event,
-    ):
-        messaging = {
-            "pre_disable": pre_disable_msg,
-            "post_disable": post_disable_msg,
-        }
-        m_should_reboot.return_value = False
-        with mock.patch.object(type(entitlement), "messaging", messaging):
-            with mock.patch.object(type(entitlement), "packages", []):
-                ret, fail = entitlement.disable()
-                assert retval == ret
-        stdout, _ = capsys.readouterr()
-        assert output == stdout
-
-    @pytest.mark.parametrize("should_reboot", (False, True))
     @pytest.mark.parametrize("with_pre_install_msg", (False, True))
     @pytest.mark.parametrize("packages", (["a"], [], None))
     @pytest.mark.parametrize(
@@ -435,7 +351,6 @@ class TestRepoEnable:
     )
     @mock.patch("uaclient.apt.update_sources_list")
     @mock.patch("uaclient.apt.setup_apt_proxy")
-    @mock.patch(M_PATH + "system.should_reboot")
     @mock.patch(M_PATH + "system.subp", return_value=("", ""))
     @mock.patch(M_PATH + "apt.add_auth_apt_repo")
     @mock.patch(M_PATH + "exists", return_value=True)
@@ -450,7 +365,6 @@ class TestRepoEnable:
         m_exists,
         m_apt_add,
         m_subp,
-        m_should_reboot,
         m_setup_apt_proxy,
         m_update_sources_list,
         entitlement,
@@ -461,11 +375,9 @@ class TestRepoEnable:
         series,
         file_extension,
         with_pre_install_msg,
-        should_reboot,
     ):
         """On enable add authenticated apt repo and refresh package lists."""
         m_release_info.return_value = mock.MagicMock(series=series)
-        m_should_reboot.return_value = should_reboot
 
         pre_install_msgs = ["Some pre-install information", "Some more info"]
         if with_pre_install_msg:
@@ -478,18 +390,14 @@ class TestRepoEnable:
             messaging_patch = mock.MagicMock()
 
         expected_apt_calls = []
-
-        reboot_msg = "A reboot is required to complete install."
-        expected_output = (
-            "\n".join(
-                [
-                    "Updating Repo Test Class package lists",
-                    "Repo Test Class enabled",
-                ]
-                + ([reboot_msg] if should_reboot else [])
-            )
-            + "\n"
-        )
+        expected_emit_calls = [
+            mock.call("message_operation", None),
+            mock.call("message_operation", None),
+        ]
+        expected_progress_calls = [
+            mock.call("Configuring APT access to Repo Test Class"),
+            mock.call("Updating Repo Test Class package lists"),
+        ]
 
         update_sources_list_call_count = 1
         if packages is not None:
@@ -508,26 +416,30 @@ class TestRepoEnable:
                         override_env_vars=None,
                     )
                 )
-                expected_output = (
-                    "\n".join(
-                        ["Updating Repo Test Class package lists"]
-                        + (pre_install_msgs if with_pre_install_msg else [])
-                        + ["Updating standard Ubuntu package lists"]
-                        + [
-                            "Installing Repo Test Class packages",
-                            "Repo Test Class enabled",
-                        ]
-                        + ([reboot_msg] if should_reboot else [])
-                    )
-                    + "\n"
-                )
+                expected_emit_calls = [
+                    mock.call("message_operation", None),
+                    mock.call("message_operation", None),
+                    mock.call(
+                        "message_operation",
+                        pre_install_msgs if with_pre_install_msg else None,
+                    ),
+                    mock.call(
+                        "info", "Updating standard Ubuntu package lists"
+                    ),
+                ]
+                expected_progress_calls = [
+                    mock.call("Configuring APT access to Repo Test Class"),
+                    mock.call("Updating Repo Test Class package lists"),
+                    mock.call("Installing Repo Test Class packages"),
+                ]
         else:
             packages = entitlement.packages
 
+        progress_mock = mock.MagicMock()
         # We patch the type of entitlement because packages is a property
         with mock.patch.object(type(entitlement), "packages", packages):
             with messaging_patch:
-                entitlement.enable()
+                entitlement.enable(progress_mock)
 
         expected_calls = [
             mock.call(apt.APT_METHOD_HTTPS_FILE),
@@ -550,10 +462,9 @@ class TestRepoEnable:
             )
         ]
         assert add_apt_calls == m_apt_add.call_args_list
-        assert 1 == m_should_reboot.call_count
         assert 1 == m_setup_apt_proxy.call_count
-        stdout, _ = capsys.readouterr()
-        assert expected_output == stdout
+        assert expected_emit_calls == progress_mock.emit.call_args_list
+        assert expected_progress_calls == progress_mock.progress.call_args_list
 
     @mock.patch("uaclient.apt.setup_apt_proxy")
     @mock.patch(M_PATH + "system.subp")
@@ -578,7 +489,7 @@ class TestRepoEnable:
                         with mock.patch.object(
                             entitlement, "remove_apt_config"
                         ) as m_rac:
-                            entitlement.enable()
+                            entitlement.enable(mock.MagicMock())
 
         assert (
             "Unexpected APT error.\n"
@@ -596,35 +507,30 @@ class TestPerformEnable:
             "access_only",
             "expected_setup_apt_calls",
             "expected_install_calls",
-            "expected_check_for_reboot_calls",
         ],
         [
             (
                 False,
                 False,
-                [mock.call(silent=mock.ANY)],
-                [mock.call()],
-                [mock.call(operation="install")],
+                [mock.call(mock.ANY)],
+                [mock.call(mock.ANY)],
             ),
             (
                 False,
                 True,
-                [mock.call(silent=mock.ANY)],
-                [mock.call()],
-                [mock.call(operation="install")],
+                [mock.call(mock.ANY)],
+                [mock.call(mock.ANY)],
             ),
             (
                 True,
                 False,
-                [mock.call(silent=mock.ANY)],
-                [mock.call()],
-                [mock.call(operation="install")],
+                [mock.call(mock.ANY)],
+                [mock.call(mock.ANY)],
             ),
             (
                 True,
                 True,
-                [mock.call(silent=mock.ANY)],
-                [],
+                [mock.call(mock.ANY)],
                 [],
             ),
         ],
@@ -641,7 +547,6 @@ class TestPerformEnable:
         access_only,
         expected_setup_apt_calls,
         expected_install_calls,
-        expected_check_for_reboot_calls,
         entitlement_factory,
     ):
         with mock.patch.object(
@@ -652,18 +557,14 @@ class TestPerformEnable:
                 affordances={"series": ["xenial"]},
                 access_only=access_only,
             )
-            assert entitlement._perform_enable(silent=True) is True
+            assert entitlement._perform_enable(mock.MagicMock()) is True
             assert (
                 m_setup_apt_config.call_args_list == expected_setup_apt_calls
             )
             assert m_install_packages.call_args_list == expected_install_calls
-            assert (
-                m_check_for_reboot_msg.call_args_list
-                == expected_check_for_reboot_calls
-            )
 
 
-class TestPerformDisable:
+class TestRepoPerformDisable:
     @pytest.mark.parametrize("purge_value", (True, False))
     @mock.patch(M_PATH + "apt.get_installed_packages_by_origin")
     @mock.patch(M_PATH + "apt.get_remote_versions_for_package")
@@ -682,11 +583,18 @@ class TestPerformDisable:
         purge_value,
         entitlement_factory,
     ):
-        m_get_installed_packages.return_value = [1, 2, 3, 4, 5]
 
-        def return_alternatives(p, _exclude_origins):
-            if p % 2:
-                return [p]
+        m_packages = []
+        for i in range(1, 6):
+            package = mock.MagicMock()
+            type(package).name = mock.PropertyMock(return_value=str(i))
+            m_packages.append(package)
+
+        m_get_installed_packages.return_value = m_packages
+
+        def return_alternatives(p, exclude_origin):
+            if not int(p.name) % 2:
+                return [int(p.name)]
             return []
 
         m_get_remote_versions.side_effect = return_alternatives
@@ -697,35 +605,79 @@ class TestPerformDisable:
                 affordances={"series": ["xenial"]},
                 purge=purge_value,
             )
-            assert entitlement._perform_disable() is True
-            assert m_remove_apt_config.call_args_list == [
-                mock.call(silent=mock.ANY)
-            ]
+            assert entitlement._perform_disable(mock.MagicMock()) is True
+            assert m_remove_apt_config.call_args_list == [mock.call(mock.ANY)]
 
             if purge_value:
-                m_get_installed_packages.call_args_list = [
+                assert m_get_installed_packages.call_args_list == [
                     mock.call("TestOrigin")
                 ]
-                m_get_remote_versions.call_args_list = [
-                    mock.call(1, exclude_origin="TestOrigin"),
-                    mock.call(2, exclude_origin="TestOrigin"),
-                    mock.call(3, exclude_origin="TestOrigin"),
-                    mock.call(4, exclude_origin="TestOrigin"),
-                    mock.call(5, exclude_origin="TestOrigin"),
+                assert m_get_remote_versions.call_args_list == [
+                    mock.call(m_packages[0], exclude_origin="TestOrigin"),
+                    mock.call(m_packages[1], exclude_origin="TestOrigin"),
+                    mock.call(m_packages[2], exclude_origin="TestOrigin"),
+                    mock.call(m_packages[3], exclude_origin="TestOrigin"),
+                    mock.call(m_packages[4], exclude_origin="TestOrigin"),
                 ]
-                m_prompt_for_purge.call_args_list = [
-                    mock.call([1, 3, 5], [(2, 2), (4, 4)])
+                assert m_prompt_for_purge.call_args_list == [
+                    mock.call(
+                        [m_packages[0], m_packages[2], m_packages[4]],
+                        [(m_packages[1], 2), (m_packages[3], 4)],
+                        mock.ANY,
+                    )
                 ]
-                m_execute_removal.call_args_list = [mock.call([1, 3, 5])]
-                m_execute_reinstall.call_args_list = [
-                    mock.call([(2, 2), (4, 4)])
+                assert m_execute_removal.call_args_list == [
+                    mock.call([m_packages[0], m_packages[2], m_packages[4]])
+                ]
+                assert m_execute_reinstall.call_args_list == [
+                    mock.call([(m_packages[1], 2), (m_packages[3], 4)])
                 ]
             else:
-                m_get_installed_packages.call_args_list = []
-                m_get_remote_versions.call_args_list = []
-                m_prompt_for_purge.call_args_list = []
-                m_execute_removal.call_args_list = []
-                m_execute_reinstall.call_args_list = []
+                assert m_get_installed_packages.call_args_list == []
+                assert m_get_remote_versions.call_args_list == []
+                assert m_prompt_for_purge.call_args_list == []
+                assert m_execute_removal.call_args_list == []
+                assert m_execute_reinstall.call_args_list == []
+
+    @pytest.mark.parametrize(
+        "repo_cls",
+        (
+            (RepoTestEntitlement),
+            (RepoTestEntitlementRepoWithRemovePackages),
+        ),
+    )
+    @mock.patch("uaclient.system.should_reboot", return_value=False)
+    def test_disable_on_can_disable_true_removes_apt_config_and_packages(
+        self,
+        _m_should_reboot,
+        repo_cls,
+        entitlement_factory,
+    ):
+        """When can_disable, disable removes apt config and packages."""
+        entitlement = entitlement_factory(repo_cls)
+
+        if isinstance(entitlement, RepoTestEntitlementRepoWithRemovePackages):
+            mock_remove_packages = mock.patch.object(
+                entitlement, "remove_packages"
+            )
+        else:
+            mock_remove_packages = mock.MagicMock()
+
+        with mock.patch.object(
+            entitlement, "can_disable", return_value=(True, None)
+        ):
+            with mock.patch.object(
+                entitlement, "remove_apt_config"
+            ) as m_remove_apt_config:
+                with mock_remove_packages as m_remove_packages:
+                    assert entitlement.disable(mock.MagicMock())
+
+        assert [mock.call(mock.ANY)] == m_remove_apt_config.call_args_list
+
+        if isinstance(entitlement, RepoTestEntitlementRepoWithRemovePackages):
+            assert [mock.call()] == m_remove_packages.call_args_list
+        else:
+            assert 0 == m_remove_packages.call_count
 
 
 class TestPurge:
@@ -749,14 +701,19 @@ class TestPurge:
             purge=True,
         )
 
-        assert entitlement.purge_kernel_check(self.packages_to_remove) is True
+        assert (
+            entitlement.purge_kernel_check(
+                self.packages_to_remove, mock.MagicMock()
+            )
+            is True
+        )
 
     @mock.patch(
         M_PATH + "system.get_installed_ubuntu_kernels", return_value=[]
     )
     @mock.patch(M_PATH + "system.get_kernel_info")
     def test_purge_kernel_check_false_when_no_other_kernels(
-        self, _m_kernel_info, _m_installed_kernels, entitlement_factory, capsys
+        self, _m_kernel_info, _m_installed_kernels, entitlement_factory
     ):
         entitlement = entitlement_factory(
             RepoTestEntitlement,
@@ -764,17 +721,30 @@ class TestPurge:
             purge=True,
         )
 
+        mock_progress = mock.MagicMock()
         assert (
-            entitlement.purge_kernel_check(self.mock_kernel_package) is False
+            entitlement.purge_kernel_check(
+                self.mock_kernel_package, mock_progress
+            )
+            is False
+        )
+        assert (
+            mock.call(
+                "info",
+                (
+                    "No other valid Ubuntu kernel was found in the system.\n"
+                    "Removing the package would potentially make the system "
+                    "unbootable.\n"
+                    "Aborting.\n"
+                ),
+            )
+            in mock_progress.emit.call_args_list
         )
-        out, _err = capsys.readouterr()
-        assert "No other valid Ubuntu kernel was found in the system" in out
 
     @pytest.mark.parametrize("prompt_answer", (True, False))
     @pytest.mark.parametrize(
         "current_kernel", ("1.2.3-4-fake", "2.3.4-5-fake")
     )
-    @mock.patch(M_PATH + "util.prompt_for_confirmation")
     @mock.patch(
         M_PATH + "system.get_installed_ubuntu_kernels",
         return_value=["2.3.4-5-fake"],
@@ -784,33 +754,56 @@ class TestPurge:
         self,
         m_kernel_info,
         _m_installed_kernels,
-        m_confirmation,
         prompt_answer,
         current_kernel,
         entitlement_factory,
-        capsys,
     ):
         m_kernel_info.return_value.uname_release = current_kernel
-        m_confirmation.return_value = prompt_answer
         entitlement = entitlement_factory(
             RepoTestEntitlement,
             affordances={"series": ["xenial"]},
             purge=True,
         )
 
-        assert (
-            entitlement.purge_kernel_check(self.mock_kernel_package)
-            is prompt_answer
+        mock_progress = mock.MagicMock()
+
+        def fake_emit(name, payload):
+            if name == "message_operation" and prompt_answer is False:
+                raise exceptions.PromptDeniedError()
+
+        mock_progress.emit.side_effect = fake_emit
+
+        expect_raises = (
+            does_not_raise()
+            if prompt_answer
+            else pytest.raises(exceptions.PromptDeniedError)
         )
+        with expect_raises:
+            entitlement.purge_kernel_check(
+                self.mock_kernel_package, mock_progress
+            )
 
-        out, _err = capsys.readouterr()
-        assert "would uninstall the following kernel(s):" in out
         assert (
-            "{} is the current running kernel.".format(current_kernel) in out
+            mock.call(
+                "info",
+                messages.PURGE_KERNEL_REMOVAL.format(
+                    service="Repo Test Class"
+                ),
+            )
+            in mock_progress.emit.call_args_list
+        )
+        assert (
+            mock.call(
+                "info",
+                messages.PURGE_CURRENT_KERNEL.format(
+                    kernel_version=current_kernel
+                ),
+            )
+            in mock_progress.emit.call_args_list
         )
 
     @pytest.mark.parametrize(
-        "remove,reinstall,expected_print,expected_prompt",
+        ["remove", "reinstall", "expected_print", "expected_progress_emits"],
         (
             (
                 packages_to_remove,
@@ -819,45 +812,66 @@ class TestPurge:
                     mock.call(["remove1", "remove2"]),
                     mock.call(["reinstall1", "reinstall2"]),
                 ],
-                [mock.call(messages.PROCEED_YES_NO)],
+                [
+                    mock.call("info", messages.WARN_PACKAGES_REMOVAL),
+                    mock.call("info", "  remove1 remove2\n"),
+                    mock.call("info", messages.WARN_PACKAGES_REINSTALL),
+                    mock.call("info", "  reinstall1 reinstall2\n"),
+                    mock.call(
+                        "message_operation",
+                        [(mock.ANY, {"msg": messages.PROCEED_YES_NO})],
+                    ),
+                ],
             ),
             (
                 packages_to_remove,
                 [],
                 [mock.call(["remove1", "remove2"])],
-                [mock.call(messages.PROCEED_YES_NO)],
+                [
+                    mock.call("info", messages.WARN_PACKAGES_REMOVAL),
+                    mock.call("info", "  remove1 remove2\n"),
+                    mock.call(
+                        "message_operation",
+                        [(mock.ANY, {"msg": messages.PROCEED_YES_NO})],
+                    ),
+                ],
             ),
             (
                 [],
                 packages_to_reinstall,
                 [mock.call(["reinstall1", "reinstall2"])],
-                [mock.call(messages.PROCEED_YES_NO)],
+                [
+                    mock.call("info", messages.WARN_PACKAGES_REINSTALL),
+                    mock.call("info", "  reinstall1 reinstall2\n"),
+                    mock.call(
+                        "message_operation",
+                        [(mock.ANY, {"msg": messages.PROCEED_YES_NO})],
+                    ),
+                ],
             ),
             ([], [], [], []),
         ),
     )
-    @mock.patch(M_PATH + "util.print_package_list")
-    @mock.patch(M_PATH + "util.prompt_for_confirmation")
     def test_prompt_for_purge(
         self,
-        m_confirmation,
-        m_print_packages,
         remove,
         reinstall,
         expected_print,
-        expected_prompt,
+        expected_progress_emits,
         entitlement_factory,
     ):
-        m_confirmation.return_value = True
         entitlement = entitlement_factory(
             RepoTestEntitlement,
             affordances={"series": ["xenial"]},
             purge=True,
         )
 
-        assert entitlement.prompt_for_purge(remove, reinstall) is True
-        assert m_print_packages.call_args_list == expected_print
-        assert m_confirmation.call_args_list == expected_prompt
+        mock_progress = mock.MagicMock()
+        assert (
+            entitlement.prompt_for_purge(remove, reinstall, mock_progress)
+            is True
+        )
+        assert mock_progress.emit.call_args_list == expected_progress_emits
 
     @pytest.mark.parametrize(
         "remove,expected_remove",
@@ -948,7 +962,7 @@ class TestRemoveAptConfig:
         entitlement = entitlement_factory(RepoTestEntitlement, directives={})
 
         with pytest.raises(exceptions.MissingAptURLDirective) as excinfo:
-            entitlement.remove_apt_config()
+            entitlement.remove_apt_config(mock.MagicMock())
 
         assert "repotest" in str(excinfo.value)
 
@@ -958,7 +972,7 @@ class TestRemoveAptConfig:
     def test_apt_get_update_called(
         self, m_run_apt_update_command, _m_apt1, _m_apt2, entitlement
     ):
-        entitlement.remove_apt_config()
+        entitlement.remove_apt_config(mock.MagicMock())
 
         assert mock.call() in m_run_apt_update_command.call_args_list
 
@@ -981,7 +995,7 @@ class TestRemoveAptConfig:
             RepoTestEntitlement,
             affordances={"series": ["xenial"]},
         )
-        entitlement.remove_apt_config()
+        entitlement.remove_apt_config(mock.MagicMock())
 
         assert [
             mock.call("http://REPOTEST", "xenial")
@@ -1018,7 +1032,7 @@ class TestRemoveAptConfig:
         )
 
         assert 1000 == entitlement.repo_pin_priority
-        entitlement.remove_apt_config()
+        entitlement.remove_apt_config(mock.MagicMock())
         assert [
             mock.call("/etc/apt/preferences.d/ubuntu-repotest")
         ] == m_ensure_file_absent.call_args_list
@@ -1064,7 +1078,7 @@ class TestSetupAptConfig:
         entitlement = entitlement_factory(repo_cls, directives=directives)
 
         with pytest.raises(exc_cls) as excinfo:
-            entitlement.setup_apt_config()
+            entitlement.setup_apt_config(mock.MagicMock())
         assert err_msg in str(excinfo.value)
 
     @pytest.mark.parametrize("enable_by_default", (True, False))
@@ -1092,7 +1106,7 @@ class TestSetupAptConfig:
         # Drop resourceTokens values from base machine-token.
         machine_token["resourceTokens"] = []
         entitlement.cfg.machine_token_file.write(machine_token)
-        entitlement.setup_apt_config()
+        entitlement.setup_apt_config(mock.MagicMock())
         expected_msg = (
             "No resourceToken present in contract for service Repo Test"
             " Class. Using machine token as credentials"
@@ -1119,7 +1133,7 @@ class TestSetupAptConfig:
         entitlement,
     ):
         """Calls apt.setup_apt_proxy()"""
-        entitlement.setup_apt_config()
+        entitlement.setup_apt_config(mock.MagicMock())
         assert [
             mock.call(http_proxy=None, https_proxy=None, proxy_scope=None)
         ] == m_setup_apt_proxy.call_args_list
@@ -1143,7 +1157,7 @@ class TestSetupAptConfig:
         """
         with mock.patch(M_PATH + "exists") as m_exists:
             m_exists.return_value = False
-            entitlement.setup_apt_config()
+            entitlement.setup_apt_config(mock.MagicMock())
         assert [
             mock.call("/usr/lib/apt/methods/https"),
             mock.call("/usr/sbin/update-ca-certificates"),
@@ -1164,7 +1178,7 @@ class TestSetupAptConfig:
             RepoTestEntitlementRepoWithPin, affordances={"series": ["xenial"]}
         )
         with pytest.raises(exceptions.UbuntuProError) as excinfo:
-            entitlement.setup_apt_config()
+            entitlement.setup_apt_config(mock.MagicMock())
         assert (
             "Cannot setup apt pin. Empty apt repo origin value for repotest"
             in str(excinfo.value)
@@ -1196,7 +1210,7 @@ class TestSetupAptConfig:
         entitlement.origin = "RepoTestOrigin"  # don't error on origin = None
         with mock.patch(M_PATH + "exists") as m_exists:
             m_exists.return_value = True  # Skip prerequisite pkg installs
-            entitlement.setup_apt_config()
+            entitlement.setup_apt_config(mock.MagicMock())
         assert [
             mock.call("/usr/lib/apt/methods/https"),
             mock.call("/usr/sbin/update-ca-certificates"),
@@ -1270,7 +1284,10 @@ class TestApplicationStatus:
         """Report ENABLED when apt-policy lists specific aptURL."""
         entitlement = entitlement_factory(
             RepoTestEntitlement,
-            directives={"aptURL": "https://esm.ubuntu.com"},
+            directives={
+                "aptURL": "https://esm.ubuntu.com",
+                "suites": ["bionic-updates", "bionic-security"],
+            },
         )
 
         policy_lines = [
@@ -1320,6 +1337,6 @@ class TestHandleMessageOperations:
     def test_handle_message_operations_for_strings_and_callables(
         self, msg_ops, retval, output, capsys
     ):
-        assert retval is util.handle_message_operations(msg_ops)
+        assert retval is util.handle_message_operations(msg_ops, print)
         out, _err = capsys.readouterr()
         assert output == out
