@@ -4,8 +4,8 @@ import mock
 import pytest
 
 from uaclient import apt_news, messages
+from uaclient.api.u.pro.status.is_attached.v1 import ContractExpiryStatus
 from uaclient.clouds.identity import NoCloudTypeReason
-from uaclient.contract import ContractExpiryStatus
 
 M_PATH = "uaclient.apt_news."
 
@@ -14,15 +14,34 @@ NOW = datetime.now(timezone.utc)
 
 class TestAptNews:
     @pytest.mark.parametrize(
-        ["selectors", "series", "cloud_type", "attached", "expected"],
+        [
+            "selectors",
+            "series",
+            "cloud_type",
+            "attached",
+            "architecture",
+            "package_version_side_effect",
+            "expected",
+        ],
         [
             (
                 apt_news.AptNewsMessageSelectors(),
                 "xenial",
                 (None, NoCloudTypeReason.NO_CLOUD_DETECTED),
                 False,
+                None,
+                None,
                 True,
             ),
+            (
+                apt_news.AptNewsMessageSelectors(codenames=["bionic"]),
+                "xenial",
+                (None, NoCloudTypeReason.NO_CLOUD_DETECTED),
+                False,
+                None,
+                None,
+                False,
+            ),
             (
                 apt_news.AptNewsMessageSelectors(
                     codenames=["bionic", "xenial"]
@@ -30,15 +49,10 @@ class TestAptNews:
                 "xenial",
                 (None, NoCloudTypeReason.NO_CLOUD_DETECTED),
                 False,
+                None,
+                None,
                 True,
             ),
-            (
-                apt_news.AptNewsMessageSelectors(codenames=["bionic"]),
-                "xenial",
-                (None, NoCloudTypeReason.NO_CLOUD_DETECTED),
-                False,
-                False,
-            ),
             (
                 apt_news.AptNewsMessageSelectors(
                     codenames=["xenial"], pro=True
@@ -46,6 +60,8 @@ class TestAptNews:
                 "xenial",
                 (None, NoCloudTypeReason.NO_CLOUD_DETECTED),
                 False,
+                None,
+                None,
                 False,
             ),
             (
@@ -55,24 +71,8 @@ class TestAptNews:
                 "xenial",
                 (None, NoCloudTypeReason.NO_CLOUD_DETECTED),
                 True,
-                True,
-            ),
-            (
-                apt_news.AptNewsMessageSelectors(
-                    codenames=["bionic"], pro=False
-                ),
-                "xenial",
-                (None, NoCloudTypeReason.NO_CLOUD_DETECTED),
-                False,
-                False,
-            ),
-            (
-                apt_news.AptNewsMessageSelectors(
-                    codenames=["bionic"], pro=False
-                ),
-                "bionic",
-                (None, NoCloudTypeReason.NO_CLOUD_DETECTED),
-                False,
+                None,
+                None,
                 True,
             ),
             (
@@ -84,6 +84,8 @@ class TestAptNews:
                 "bionic",
                 (None, NoCloudTypeReason.NO_CLOUD_DETECTED),
                 False,
+                None,
+                None,
                 False,
             ),
             (
@@ -95,17 +97,111 @@ class TestAptNews:
                 "bionic",
                 (None, NoCloudTypeReason.CLOUD_ID_ERROR),
                 False,
+                None,
+                None,
                 False,
             ),
+            (
+                apt_news.AptNewsMessageSelectors(
+                    pro=False, architectures=["amd64"]
+                ),
+                "xenial",
+                (None, NoCloudTypeReason.NO_CLOUD_DETECTED),
+                False,
+                "amd64",
+                None,
+                True,
+            ),
+            (
+                apt_news.AptNewsMessageSelectors(
+                    pro=False, architectures=["arm64"]
+                ),
+                "xenial",
+                (None, NoCloudTypeReason.NO_CLOUD_DETECTED),
+                False,
+                "amd64",
+                None,
+                False,
+            ),
+            (
+                apt_news.AptNewsMessageSelectors(
+                    pro=True, packages=[["not-desktop", "==", "1.0.0"]]
+                ),
+                "xenial",
+                (None, NoCloudTypeReason.NO_CLOUD_DETECTED),
+                True,
+                None,
+                ["1.0.0"],
+                True,
+            ),
+            (
+                apt_news.AptNewsMessageSelectors(
+                    pro=True, packages=[["desktop", "==", "1.0.0"]]
+                ),
+                "xenial",
+                (None, NoCloudTypeReason.NO_CLOUD_DETECTED),
+                True,
+                None,
+                [None],
+                False,
+            ),
+            (
+                apt_news.AptNewsMessageSelectors(
+                    pro=False, packages=[["not-desktop", "=="]]
+                ),
+                "xenial",
+                (None, NoCloudTypeReason.NO_CLOUD_DETECTED),
+                False,
+                None,
+                ["1.0.0"],
+                False,
+            ),
+            (
+                apt_news.AptNewsMessageSelectors(
+                    pro=False, packages=[["not-desktop", "==", "1.0.0"]]
+                ),
+                "xenial",
+                (None, NoCloudTypeReason.NO_CLOUD_DETECTED),
+                False,
+                None,
+                ["1.0.1"],
+                False,
+            ),
+            (
+                apt_news.AptNewsMessageSelectors(
+                    pro=False, packages=[["not-desktop", ">", "1.0.0"]]
+                ),
+                "xenial",
+                (None, NoCloudTypeReason.NO_CLOUD_DETECTED),
+                False,
+                None,
+                ["1.0.1"],
+                True,
+            ),
+            (
+                apt_news.AptNewsMessageSelectors(
+                    pro=False, packages=[["not-desktop", "<", "1.0.0"]]
+                ),
+                "xenial",
+                (None, NoCloudTypeReason.NO_CLOUD_DETECTED),
+                False,
+                None,
+                ["0.0.1"],
+                True,
+            ),
             (
                 apt_news.AptNewsMessageSelectors(
                     codenames=["bionic"],
                     pro=False,
                     clouds=["gce"],
+                    architectures=["amd64"],
+                    packages=[["not-desktop", ">", "1.0.0"]],
                 ),
                 "bionic",
                 ("aws", None),
                 False,
+                "arm4",
+                ["0.0.7"],
                 False,
             ),
             (
@@ -113,24 +209,53 @@ class TestAptNews:
                     codenames=["bionic"],
                     pro=False,
                     clouds=["gce"],
+                    architectures=["amd64"],
+                    packages=[["not-desktop", ">", "1.0.0"]],
                 ),
                 "bionic",
                 ("gce", None),
                 False,
+                "amd64",
+                ["1.0.1"],
+                True,
+            ),
+            (
+                apt_news.AptNewsMessageSelectors(
+                    codenames=["bionic"],
+                    pro=False,
+                    clouds=["gce"],
+                    architectures=["amd64"],
+                    packages=[
+                        ["does-not-match", "<", "4~"],
+                        ["matches", ">", "1.0.0"],
+                        ["not-installed", "<", "1"],
+                    ],
+                ),
+                "bionic",
+                ("gce", None),
+                False,
+                "amd64",
+                ["4", "1.0.1", None],
                 True,
             ),
         ],
     )
     @mock.patch(M_PATH + "get_cloud_type")
     @mock.patch(M_PATH + "system.get_release_info")
+    @mock.patch(M_PATH + "system.get_dpkg_arch")
+    @mock.patch(M_PATH + "get_pkg_version")
     def test_do_selectors_apply(
         self,
+        m_get_pkg_version,
+        m_get_dpkg_arch,
         m_get_platform_info,
         m_get_cloud_type,
         selectors,
         series,
         cloud_type,
         attached,
+        architecture,
+        package_version_side_effect,
         expected,
         FakeConfig,
     ):
@@ -140,6 +265,8 @@ class TestAptNews:
             cfg = FakeConfig()
         m_get_platform_info.return_value = mock.MagicMock(series=series)
         m_get_cloud_type.return_value = cloud_type
+        m_get_dpkg_arch.return_value = architecture
+        m_get_pkg_version.side_effect = package_version_side_effect
         assert expected == apt_news.do_selectors_apply(cfg, selectors)
 
     @pytest.mark.parametrize(
@@ -466,50 +593,62 @@ class TestAptNews:
     @pytest.mark.parametrize(
         [
             "expiry_status",
+            "remaining_days",
             "expected",
         ],
         [
             (
-                (ContractExpiryStatus.ACTIVE, 0),
+                ContractExpiryStatus.ACTIVE,
+                0,
                 None,
             ),
             (
-                (ContractExpiryStatus.NONE, 0),
+                ContractExpiryStatus.NONE,
+                0,
                 None,
             ),
             (
-                (ContractExpiryStatus.ACTIVE_EXPIRED_SOON, 10),
+                ContractExpiryStatus.ACTIVE_EXPIRED_SOON,
+                10,
                 messages.CONTRACT_EXPIRES_SOON.pluralize(10).format(
                     remaining_days=10
                 ),
             ),
             (
-                (ContractExpiryStatus.ACTIVE_EXPIRED_SOON, 15),
+                ContractExpiryStatus.ACTIVE_EXPIRED_SOON,
+                15,
                 messages.CONTRACT_EXPIRES_SOON.pluralize(15).format(
                     remaining_days=15
                 ),
             ),
             (
-                (ContractExpiryStatus.EXPIRED_GRACE_PERIOD, -4),
+                ContractExpiryStatus.EXPIRED_GRACE_PERIOD,
+                -4,
                 messages.CONTRACT_EXPIRED_GRACE_PERIOD.pluralize(10).format(
                     remaining_days=10, expired_date="21 Dec 2012"
                 ),
             ),
             (
-                (ContractExpiryStatus.EXPIRED, -15),
+                ContractExpiryStatus.EXPIRED,
+                -15,
                 messages.CONTRACT_EXPIRED,
             ),
         ],
     )
-    @mock.patch(M_PATH + "get_contract_expiry_status")
+    @mock.patch(M_PATH + "_is_attached")
     def test_local_apt_news(
         self,
-        m_get_contract_expiry_status,
+        m_is_attached,
         expiry_status,
+        remaining_days,
         expected,
         FakeConfig,
     ):
-        m_get_contract_expiry_status.return_value = expiry_status
+        m_is_attached.return_value = mock.MagicMock(
+            is_attached=True,
+            contract_status=expiry_status.value,
+            contract_remaining_days=remaining_days,
+        )
 
         cfg = FakeConfig.for_attached_machine(
             effective_to=datetime(2012, 12, 21, tzinfo=timezone.utc)
