@@ -1,19 +1,14 @@
 import copy
-import datetime
-import itertools
 import json
 import os
-import stat
 
 import mock
 import pytest
 
 from uaclient import apt, exceptions, http, messages
 from uaclient.config import (
-    PRIVATE_SUBDIR,
     UA_CONFIGURABLE_KEYS,
     VALID_UA_CONFIG_KEYS,
-    DataPath,
     get_config_path,
     parse_config,
 )
@@ -21,15 +16,12 @@ from uaclient.conftest import FakeNotice
 from uaclient.defaults import DEFAULT_CONFIG_FILE
 from uaclient.entitlements import valid_services
 from uaclient.entitlements.entitlement_status import ApplicationStatus
-from uaclient.files import notices
+from uaclient.files import notices, user_config_file
 from uaclient.files.notices import NoticesManager
 from uaclient.util import depth_first_merge_overlay_dict
 from uaclient.yaml import safe_dump
 
-KNOWN_DATA_PATHS = (
-    ("machine-access-cis", "machine-access-cis.json"),
-    ("instance-id", "instance-id"),
-)
+KNOWN_DATA_PATHS = (("machine-id", "machine-id"),)
 M_PATH = "uaclient.entitlements."
 
 
@@ -75,13 +67,13 @@ class TestNotices:
         (
             ([], ()),
             (
-                [[FakeNotice.a2, "a1"]],
+                [[FakeNotice.reboot_script_failed, "a1"]],
                 ["a1"],
             ),
             (
                 [
-                    [FakeNotice.a, "a1"],
-                    [FakeNotice.a2, "a2"],
+                    [FakeNotice.reboot_required, "a1"],
+                    [FakeNotice.reboot_script_failed, "a2"],
                 ],
                 [
                     "a1",
@@ -90,8 +82,8 @@ class TestNotices:
             ),
             (
                 [
-                    [FakeNotice.a, "a1"],
-                    [FakeNotice.a, "a1"],
+                    [FakeNotice.reboot_required, "a1"],
+                    [FakeNotice.reboot_required, "a1"],
                 ],
                 [
                     "a1",
@@ -117,11 +109,11 @@ class TestNotices:
         "_notices",
         (
             ([]),
-            ([[FakeNotice.a]]),
+            ([[FakeNotice.reboot_required]]),
             (
                 [
-                    [FakeNotice.a],
-                    [FakeNotice.a2],
+                    [FakeNotice.reboot_required],
+                    [FakeNotice.reboot_script_failed],
                 ]
             ),
         ),
@@ -140,29 +132,29 @@ class TestNotices:
     @pytest.mark.parametrize(
         "notices_,removes,expected",
         (
-            ([], [FakeNotice.a], []),
+            ([], [FakeNotice.reboot_required], []),
             (
-                [[FakeNotice.a2]],
-                [FakeNotice.a2],
+                [[FakeNotice.reboot_script_failed]],
+                [FakeNotice.reboot_script_failed],
                 [],
             ),
             (
                 [
-                    [FakeNotice.a],
-                    [FakeNotice.a2],
+                    [FakeNotice.reboot_required],
+                    [FakeNotice.reboot_script_failed],
                 ],
-                [FakeNotice.a],
+                [FakeNotice.reboot_required],
                 ["notice_a2"],
             ),
             (
                 [
-                    [FakeNotice.a],
-                    [FakeNotice.a2],
-                    [FakeNotice.b],
+                    [FakeNotice.reboot_required],
+                    [FakeNotice.reboot_script_failed],
+                    [FakeNotice.enable_reboot_required],
                 ],
                 [
-                    FakeNotice.a,
-                    FakeNotice.a2,
+                    FakeNotice.reboot_required,
+                    FakeNotice.reboot_script_failed,
                 ],
                 ["notice_b"],
             ),
@@ -270,53 +262,16 @@ class TestAccounts:
         assert accountInfo == cfg.machine_token_file.account
 
 
-class TestDataPath:
-    def test_data_path_returns_data_dir_path_without_key(self, FakeConfig):
-        """The data_path method returns the data_dir when key is absent."""
-        cfg = FakeConfig({"data_dir": "/my/dir"})
-        assert "/my/dir/{}".format(PRIVATE_SUBDIR) == cfg.data_path()
-
-    @pytest.mark.parametrize("key,path_basename", KNOWN_DATA_PATHS)
-    def test_data_path_returns_file_path_with_defined_data_paths(
-        self, key, path_basename, FakeConfig
-    ):
-        """When key is defined in Config.data_paths return data_path value."""
-        cfg = FakeConfig({"data_dir": "/my/dir"})
-        private_path = "/my/dir/{}/{}".format(PRIVATE_SUBDIR, path_basename)
-        assert private_path == cfg.data_path(key=key)
-
-    @pytest.mark.parametrize(
-        "key,path_basename", (("notHere", "notHere"), ("anything", "anything"))
-    )
-    def test_data_path_returns_file_path_with_undefined_data_paths(
-        self, key, path_basename, FakeConfig
-    ):
-        """When key is not in Config.data_paths the key is used to data_dir"""
-        cfg = FakeConfig({"data_dir": "/my/d"})
-        assert "/my/d/{}/{}".format(PRIVATE_SUBDIR, key) == cfg.data_path(
-            key=key
-        )
-
-    def test_data_path_returns_public_path_for_public_datapath(
-        self, FakeConfig
-    ):
-        cfg = FakeConfig({"data_dir": "/my/d"})
-        cfg.data_paths["test_path"] = DataPath("test_path", False)
-        assert "/my/d/test_path" == cfg.data_path("test_path")
-
-
 CFG_BASE_CONTENT = """\
 # Ubuntu Pro client config file.
 # If you modify this file, run "pro refresh config" to ensure changes are
 # picked up by Ubuntu Pro client.
 
 contract_url: https://contracts.canonical.com
-daemon_log_file: /var/log/ubuntu-advantage-daemon.log
 data_dir: /var/lib/ubuntu-advantage
 log_file: /var/log/ubuntu-advantage.log
 log_level: debug
 security_url: https://ubuntu.com/security
-timer_log_file: /var/log/ubuntu-advantage-timer.log
 """
 
 CFG_FEATURES_CONTENT = """\
@@ -325,7 +280,6 @@ CFG_FEATURES_CONTENT = """\
 # picked up by Ubuntu Pro client.
 
 contract_url: https://contracts.canonical.com
-daemon_log_file: /var/log/ubuntu-advantage-daemon.log
 data_dir: /var/lib/ubuntu-advantage
 features:
   extra_security_params:
@@ -338,7 +292,6 @@ security_url: https://ubuntu.com/security
 settings_overrides:
   c: 1
   d: 2
-timer_log_file: /var/log/ubuntu-advantage-timer.log
 """
 
 USER_CFG_DICT = {
@@ -359,7 +312,7 @@ USER_CFG_DICT = {
 
 class TestUserConfigKeys:
     @pytest.mark.parametrize("attr_name", UA_CONFIGURABLE_KEYS)
-    @mock.patch("uaclient.config.state_files.user_config_file.write")
+    @mock.patch("uaclient.config.user_config_file.user_config.write")
     def test_user_configurable_keys_set_user_config(
         self, write, attr_name, tmpdir, FakeConfig
     ):
@@ -373,279 +326,6 @@ class TestUserConfigKeys:
             assert attr_name + "value" == getattr(cfg.user_config, attr_name)
 
 
-class TestWriteCache:
-    @pytest.mark.parametrize(
-        "key,content",
-        (("unknownkey", "content1"), ("another-one", "content2")),
-    )
-    def test_write_cache_write_key_name_in_data_dir_when_data_path_absent(
-        self, tmpdir, FakeConfig, key, content
-    ):
-        """When key is not in data_paths, write content to data_dir/key."""
-        cfg = FakeConfig()
-        expected_path = tmpdir.join(PRIVATE_SUBDIR, key)
-
-        assert not expected_path.check(), "Found unexpected file {}".format(
-            expected_path
-        )
-        assert None is cfg.write_cache(key, content)
-        assert expected_path.check(), "Missing expected file {}".format(
-            expected_path
-        )
-        assert content == cfg.read_cache(key)
-
-    def test_write_cache_creates_secure_private_dir(self, tmpdir, FakeConfig):
-        """private_dir is created with permission 0o700."""
-        cfg = FakeConfig()
-        # unknown keys are written to the private dir
-        expected_dir = tmpdir.join(PRIVATE_SUBDIR)
-        assert None is cfg.write_cache("somekey", "somevalue")
-        assert True is os.path.isdir(
-            expected_dir.strpath
-        ), "Missing expected directory {}".format(expected_dir)
-        assert 0o700 == stat.S_IMODE(os.lstat(expected_dir.strpath).st_mode)
-
-    def test_write_cache_creates_dir_when_data_dir_does_not_exist(
-        self, tmpdir, FakeConfig
-    ):
-        """When data_dir doesn't exist, create it."""
-        tmp_subdir = tmpdir.join("does/not/exist")
-        cfg = FakeConfig({"data_dir": tmp_subdir.strpath})
-
-        assert False is os.path.isdir(
-            tmp_subdir.strpath
-        ), "Found unexpected directory {}".format(tmp_subdir)
-        assert None is cfg.write_cache("somekey", "someval")
-        assert True is os.path.isdir(
-            tmp_subdir.strpath
-        ), "Missing expected directory {}".format(tmp_subdir)
-        assert "someval" == cfg.read_cache("somekey")
-
-    @pytest.mark.parametrize(
-        "key,value", (("dictkey", {"1": "v1"}), ("listkey", [1, 2, 3]))
-    )
-    def test_write_cache_writes_json_string_when_content_not_a_string(
-        self, tmpdir, FakeConfig, key, value
-    ):
-        """When content is not a string, write a json string."""
-        cfg = FakeConfig()
-
-        expected_json_content = json.dumps(value)
-        assert None is cfg.write_cache(key, value)
-        with open(tmpdir.join(PRIVATE_SUBDIR, key).strpath, "r") as stream:
-            assert expected_json_content == stream.read()
-        assert value == cfg.read_cache(key)
-
-    @pytest.mark.parametrize(
-        "datapath,mode",
-        (
-            (DataPath("path", False), 0o644),
-            (DataPath("path", True), 0o600),
-        ),
-    )
-    def test_permissions(self, FakeConfig, datapath, mode):
-        cfg = FakeConfig()
-        cfg.data_paths = {"path": datapath}
-        cfg.write_cache("path", "")
-        assert mode == stat.S_IMODE(os.lstat(cfg.data_path("path")).st_mode)
-
-    def test_write_datetime(self, FakeConfig):
-        cfg = FakeConfig()
-        key = "test_key"
-        dt = datetime.datetime.now()
-        cfg.write_cache(key, dt)
-        with open(cfg.data_path(key)) as f:
-            assert dt.isoformat() == f.read().strip('"')
-
-
-class TestReadCache:
-    @pytest.mark.parametrize("key,path_basename", KNOWN_DATA_PATHS)
-    def test_read_cache_returns_none_when_data_path_absent(
-        self, tmpdir, FakeConfig, key, path_basename
-    ):
-        """Return None when the specified key data_path is not cached."""
-        cfg = FakeConfig()
-        assert None is cfg.read_cache(key)
-        assert not tmpdir.join(path_basename).check()
-
-    @pytest.mark.parametrize("key,path_basename", KNOWN_DATA_PATHS)
-    def test_read_cache_returns_content_when_data_path_present(
-        self, tmpdir, FakeConfig, key, path_basename
-    ):
-        cfg = FakeConfig()
-        os.makedirs(tmpdir.join(PRIVATE_SUBDIR).strpath)
-        data_path = tmpdir.join(PRIVATE_SUBDIR, path_basename)
-        with open(data_path.strpath, "w") as f:
-            f.write("content{}".format(key))
-
-        assert "content{}".format(key) == cfg.read_cache(key)
-
-    @pytest.mark.parametrize("key,path_basename", KNOWN_DATA_PATHS)
-    def test_read_cache_returns_stuctured_content_when_json_data_path_present(
-        self, tmpdir, FakeConfig, key, path_basename
-    ):
-        cfg = FakeConfig()
-        os.makedirs(tmpdir.join(PRIVATE_SUBDIR).strpath)
-        data_path = tmpdir.join(PRIVATE_SUBDIR, path_basename)
-        expected = {key: "content{}".format(key)}
-        with open(data_path.strpath, "w") as f:
-            f.write(json.dumps(expected))
-
-        assert expected == cfg.read_cache(key)
-
-    def test_datetimes_are_unserialised(self, tmpdir, FakeConfig):
-        cfg = FakeConfig()
-        os.makedirs(tmpdir.join(PRIVATE_SUBDIR).strpath)
-        data_path = tmpdir.join(PRIVATE_SUBDIR, "dt_test")
-        with open(data_path.strpath, "w") as f:
-            f.write('{"dt": "2019-07-25T14:35:51"}')
-
-        actual = cfg.read_cache("dt_test")
-        assert {
-            "dt": datetime.datetime(
-                2019, 7, 25, 14, 35, 51, tzinfo=datetime.timezone.utc
-            )
-        } == actual
-
-
-class TestDeleteCacheKey:
-    @pytest.mark.parametrize("property_name", ("status-cache", "lock"))
-    def test_delete_cache_key_removes_public_or_private_data_path_files(
-        self, property_name, FakeConfig
-    ):
-        cfg = FakeConfig()
-        cfg.write_cache(property_name, "himom")
-        assert True is os.path.exists(cfg.data_path(property_name))
-        cfg.delete_cache_key(property_name)
-        assert False is os.path.exists(cfg.data_path(property_name))
-        assert None is cfg.read_cache(property_name)
-
-    @pytest.mark.parametrize(
-        "property_name,clears_cache",
-        (
-            ("machine-token", True),
-            ("machine-access-cis", True),
-            ("machine", False),
-        ),
-    )
-    def test_delete_cache_key_clears_machine_token_and_entitlements(
-        self, property_name, clears_cache, FakeConfig, all_resources_available
-    ):
-        cfg = FakeConfig()
-        token = {
-            "availableResources": all_resources_available,
-            "machineTokenInfo": {
-                "contractInfo": {
-                    "resourceEntitlements": [
-                        {"type": "entitlement1", "entitled": True},
-                        {"type": "entitlement2", "entitled": True},
-                    ]
-                }
-            },
-        }
-        cfg.machine_token_file.write(token)
-        # sets config _entitlements and _machine_token cache
-        cfg.machine_token_file.entitlements
-        assert cfg.machine_token_file._entitlements is not None
-        assert cfg.machine_token_file._machine_token is not None
-        if property_name == "machine-token":
-            cfg.machine_token_file.delete()
-        else:
-            cfg.delete_cache_key(property_name)
-        if clears_cache:
-            # internal cache is cleared
-            assert cfg.machine_token_file._entitlements is None
-            assert cfg.machine_token_file._machine_token is None
-
-        # Reconstitutes _entitlements and _machine_token caches
-        entitlements = cfg.machine_token_file.entitlements
-        if property_name == "machine-token":
-            # We performed delete_cache_key("machine-token") above, so None now
-            assert None is cfg.machine_token_file._entitlements
-            assert None is cfg.machine_token
-        else:
-            # re-constitute from cache
-            assert entitlements is cfg.machine_token_file._entitlements
-            assert cfg.machine_token_file._machine_token is cfg.machine_token
-
-
-class TestDeleteCache:
-    def test_delete_cache_unsets_entitlements(
-        self, FakeConfig, all_resources_available
-    ):
-        """The delete_cache unsets any cached entitlements content."""
-        cfg = FakeConfig()
-        token = {
-            "availableResources": all_resources_available,
-            "machineTokenInfo": {
-                "contractInfo": {
-                    "resourceEntitlements": [
-                        {"type": "entitlement1", "entitled": True}
-                    ]
-                }
-            },
-        }
-        cfg.machine_token_file.write(token)
-        previous_entitlements = {
-            "entitlement1": {
-                "entitlement": {"type": "entitlement1", "entitled": True}
-            }
-        }
-        assert previous_entitlements == cfg.machine_token_file.entitlements
-        cfg.delete_cache()
-        cfg.machine_token_file.delete()
-        assert {} == cfg.machine_token_file.entitlements
-
-    def test_delete_cache_removes_all_data_path_files(
-        self, tmpdir, FakeConfig
-    ):
-        """Any cached files defined in cfg.data_paths will be removed."""
-        cfg = FakeConfig()
-        # Create half of the cached files, but not all
-        odd_keys = list(sorted(cfg.data_paths.keys()))[::2]
-        for odd_key in odd_keys:
-            if odd_key == "notices":
-                # notices key expects specific list or lists format
-                value = [[odd_key, odd_key]]
-            else:
-                value = odd_key
-            cfg.write_cache(odd_key, value)
-
-        present_files = list(
-            itertools.chain(
-                *[walk_entry[2] for walk_entry in os.walk(tmpdir.strpath)]
-            )
-        )
-        assert len(odd_keys) == len(present_files)
-        cfg.delete_cache()
-        dirty_files = list(
-            itertools.chain(
-                *[walk_entry[2] for walk_entry in os.walk(tmpdir.strpath)]
-            )
-        )
-        assert 0 == len(dirty_files), "{} files not deleted".format(
-            ", ".join(dirty_files)
-        )
-
-    def test_delete_cache_ignores_files_not_defined_in_data_paths(
-        self, tmpdir, FakeConfig
-    ):
-        """Any files in data_dir undefined in cfg.data_paths will remain."""
-        cfg = FakeConfig()
-        t_file = tmpdir.join(PRIVATE_SUBDIR, "otherfile")
-        os.makedirs(os.path.dirname(t_file.strpath))
-        with open(t_file.strpath, "w") as f:
-            f.write("content")
-        assert [os.path.basename(t_file.strpath)] == os.listdir(
-            tmpdir.join(PRIVATE_SUBDIR).strpath
-        )
-        cfg.delete_cache()
-        cfg.machine_token_file.delete()
-        assert [os.path.basename(t_file.strpath)] == os.listdir(
-            tmpdir.join(PRIVATE_SUBDIR).strpath
-        )
-
-
 class TestProcessConfig:
     @pytest.mark.parametrize(
         "http_proxy, https_proxy, snap_is_snapd_installed, snap_http_val, "
@@ -835,7 +515,7 @@ class TestProcessConfig:
     @mock.patch("uaclient.snap.configure_snap_proxy")
     @mock.patch("uaclient.snap.is_snapd_installed")
     @mock.patch("uaclient.apt.setup_apt_proxy")
-    @mock.patch("uaclient.config.state_files.user_config_file.write")
+    @mock.patch("uaclient.config.user_config_file.user_config.write")
     def test_process_config(
         self,
         m_write,
@@ -899,8 +579,8 @@ class TestProcessConfig:
             if ua_https or ua_http:
                 exc = True
                 with pytest.raises(
-                    exceptions.UserFacingError,
-                    match=messages.ERROR_PROXY_CONFIGURATION,
+                    exceptions.UbuntuProError,
+                    match=messages.E_INVALID_PROXY_COMBINATION.msg,
                 ):
                     cfg.process_config()
         if exc is False:
@@ -980,9 +660,11 @@ class TestProcessConfig:
         cfg.user_config.update_messaging_timer = "wrong"
 
         with pytest.raises(
-            exceptions.UserFacingError,
-            match="Value for the update_messaging_timer interval must be "
-            "a positive integer. Default value will be used.",
+            exceptions.UbuntuProError,
+            match=(
+                "Cannot set update_messaging_timer to wrong: <value> for "
+                "interval must be a positive integer."
+            ),
         ):
             cfg.process_config()
 
@@ -1004,8 +686,6 @@ class TestParseConfig:
             "security_url": "https://ubuntu.com/security",
             "data_dir": "/var/lib/ubuntu-advantage",
             "log_file": "/var/log/ubuntu-advantage.log",
-            "timer_log_file": "/var/log/ubuntu-advantage-timer.log",
-            "daemon_log_file": "/var/log/ubuntu-advantage-daemon.log",  # noqa: E501
             "log_level": "debug",
         }
         assert expected_default_config == config
@@ -1098,7 +778,7 @@ class TestParseConfig:
     ):
         user_values = {env_var: env_value}  # no acceptable url scheme
         with mock.patch.dict("uaclient.config.os.environ", values=user_values):
-            with pytest.raises(exceptions.UserFacingError) as excinfo:
+            with pytest.raises(exceptions.UbuntuProError) as excinfo:
                 parse_config()
         expected_msg = "Invalid url in config. {}: {}".format(
             env_var.replace("UA_", "").lower(), env_value
@@ -1126,7 +806,7 @@ class TestParseConfig:
         m_path_exists.return_value = False
         user_values = {"UA_FEATURES_TEST": "test.yaml"}
         with mock.patch.dict("uaclient.config.os.environ", values=user_values):
-            with pytest.raises(exceptions.UserFacingError) as excinfo:
+            with pytest.raises(exceptions.UbuntuProError) as excinfo:
                 parse_config()
 
         expected_msg = "Could not find yaml file: test.yaml"
@@ -1278,48 +958,6 @@ class TestMachineTokenOverlay:
         cfg = FakeConfig(cfg_overrides=user_cfg)
         assert self.machine_token_dict == cfg.machine_token
 
-    @mock.patch("uaclient.files.MachineTokenFile.read")
-    @mock.patch("uaclient.config.os.path.exists", return_value=False)
-    def test_machine_token_overlay_file_not_found(
-        self, m_path, m_token_read, FakeConfig
-    ):
-        invalid_path = "machine-token-path"
-        user_cfg = {"features": {"machine_token_overlay": invalid_path}}
-        m_token_read.return_value = self.machine_token_dict
-
-        cfg = FakeConfig(cfg_overrides=user_cfg)
-        expected_msg = messages.INVALID_PATH_FOR_MACHINE_TOKEN_OVERLAY.format(
-            file_path=invalid_path
-        )
-
-        with pytest.raises(exceptions.UserFacingError) as excinfo:
-            cfg.machine_token
-
-        assert expected_msg == str(excinfo.value)
-
-    @mock.patch("uaclient.system.load_file")
-    @mock.patch("uaclient.files.MachineTokenFile.read")
-    @mock.patch("uaclient.config.os.path.exists", return_value=True)
-    def test_machine_token_overlay_json_decode_error(
-        self, m_path, m_token_read, m_load_file, FakeConfig
-    ):
-        invalid_json_path = "machine-token-path"
-        user_cfg = {"features": {"machine_token_overlay": invalid_json_path}}
-        m_token_read.return_value = self.machine_token_dict
-
-        json_str = '{"directives": {"remoteServer": "overlay"}'
-        m_load_file.return_value = json_str
-        expected_msg = messages.ERROR_JSON_DECODING_IN_FILE.format(
-            error="Expecting ',' delimiter: line 1 column 43 (char 42)",
-            file_path=invalid_json_path,
-        )
-
-        cfg = FakeConfig(cfg_overrides=user_cfg)
-        with pytest.raises(exceptions.UserFacingError) as excinfo:
-            cfg.machine_token
-
-        assert expected_msg == str(excinfo.value)
-
 
 class TestDepthFirstMergeOverlayDict:
     @pytest.mark.parametrize(
@@ -1363,27 +1001,72 @@ class TestGetConfigPath:
             assert DEFAULT_CONFIG_FILE == get_config_path()
 
 
-class TestCheckLockInfo:
-    @pytest.mark.parametrize("lock_content", ((""), ("corrupted")))
-    @mock.patch("os.path.exists", return_value=True)
-    @mock.patch("uaclient.system.load_file")
-    def test_raise_exception_for_corrupted_lock(
-        self,
-        m_load_file,
-        _m_path_exists,
-        lock_content,
-        FakeConfig,
-    ):
+class TestConfigShow:
+    @mock.patch("uaclient.config.user_config_file.user_config.write")
+    def test_redact_config_data(self, _write, FakeConfig):
         cfg = FakeConfig()
-        m_load_file.return_value = lock_content
 
-        expected_msg = messages.INVALID_LOCK_FILE.format(
-            lock_file_path=cfg.data_dir + "/lock"
+        setattr(
+            cfg.user_config,
+            "apt_http_proxy",
+            "http://username:password@proxy:port",
+        )
+        setattr(
+            cfg.user_config,
+            "apt_https_proxy",
+            "http://username:password@proxy:port",
+        )
+        setattr(
+            cfg.user_config,
+            "global_apt_http_proxy",
+            "http://username:password@proxy:port",
+        )
+        setattr(
+            cfg.user_config,
+            "global_apt_https_proxy",
+            "http://username:password@proxy:port",
+        )
+        setattr(
+            cfg.user_config,
+            "ua_apt_http_proxy",
+            "http://username:password@proxy:port",
+        )
+        setattr(
+            cfg.user_config,
+            "ua_apt_https_proxy",
+            "http://username:password@proxy:port",
+        )
+        setattr(
+            cfg.user_config,
+            "http_proxy",
+            "http://username:password@proxy:port",
+        )
+        setattr(cfg.user_config, "https_proxy", "https://www.example.com")
+
+        user_config_file_object = user_config_file.UserConfigFileObject()
+        redacted_config = user_config_file_object.redact_config_data(
+            cfg.user_config
         )
 
-        with pytest.raises(exceptions.InvalidLockFile) as exc_info:
-            cfg.check_lock_info()
+        # Assert that proxy configurations are redacted
+        assert getattr(redacted_config, "apt_http_proxy") == "<REDACTED>"
+        assert getattr(redacted_config, "apt_https_proxy") == "<REDACTED>"
+        assert (
+            getattr(redacted_config, "global_apt_http_proxy") == "<REDACTED>"
+        )
+        assert (
+            getattr(redacted_config, "global_apt_https_proxy") == "<REDACTED>"
+        )
+        assert getattr(redacted_config, "ua_apt_http_proxy") == "<REDACTED>"
+        assert getattr(redacted_config, "ua_apt_https_proxy") == "<REDACTED>"
+        assert getattr(redacted_config, "http_proxy") == "<REDACTED>"
+        assert (
+            getattr(redacted_config, "https_proxy")
+            == "https://www.example.com"
+        )
 
-        assert expected_msg.msg == exc_info.value.msg
-        assert m_load_file.call_count == 1
-        assert _m_path_exists.call_count == 1
+        # Assert that redacting multiple times does not change the result
+        redacted_again = user_config_file_object.redact_config_data(
+            redacted_config
+        )
+        assert redacted_config == redacted_again
