@@ -249,7 +249,6 @@ class TestUAContractClient:
         assert {"test": "response"} == client.get_resource_machine_access(
             **kwargs
         )
-        assert {"test": "response"} == cfg.read_cache("machine-access-cis")
         params = {
             "headers": {
                 "user-agent": "UA-Client/{}".format(get_version()),
@@ -506,14 +505,12 @@ class TestUAContractClient:
     ):
         cfg = FakeConfig()
         client = UAContractClient(cfg)
-        magic_attach_token_resp = (
-            {
-                "token": "token",
-                "expires": "2100-06-09T18:14:55.323733Z",
-                "expiresIn": 600,
-                "userCode": "1234",
-            },
-        )
+        magic_attach_token_resp = {
+            "token": "token",
+            "expires": "2100-06-09T18:14:55.323733Z",
+            "expiresIn": 600,
+            "userCode": "1234",
+        }
         request_url.return_value = http.HTTPResponse(
             code=200,
             headers={},
@@ -717,7 +714,12 @@ class TestUAContractClient:
                 True,
                 "lxc",
                 "8001",
-                IsAttachedResult(is_attached=False),
+                IsAttachedResult(
+                    is_attached=False,
+                    contract_status="none",
+                    contract_remaining_days=0,
+                    is_attached_and_contract_valid=False,
+                ),
                 None,
                 None,
                 None,
@@ -755,7 +757,12 @@ class TestUAContractClient:
                 True,
                 "lxc",
                 "8001",
-                IsAttachedResult(is_attached=True),
+                IsAttachedResult(
+                    is_attached=True,
+                    contract_status="active",
+                    contract_remaining_days=100,
+                    is_attached_and_contract_valid=True,
+                ),
                 mock.MagicMock(
                     enabled_services=[
                         helpers.mock_with_name_attr(
@@ -810,7 +817,12 @@ class TestUAContractClient:
                 True,
                 "lxc",
                 "8001",
-                IsAttachedResult(is_attached=True),
+                IsAttachedResult(
+                    is_attached=True,
+                    contract_status="active",
+                    contract_remaining_days=100,
+                    is_attached_and_contract_valid=True,
+                ),
                 mock.MagicMock(
                     enabled_services=[
                         helpers.mock_with_name_attr(
@@ -1234,13 +1246,9 @@ class TestRefresh:
     @pytest.mark.parametrize(
         [
             "update_contract_machine_result",
-            "expected_write_cache_call_args",
         ],
         [
-            (
-                {"response": "val"},
-                [mock.call("machine-id", mock.sentinel.system_machine_id)],
-            ),
+            ({"response": "val"},),
             (
                 {
                     "response": "val",
@@ -1248,12 +1256,11 @@ class TestRefresh:
                         "machineId": mock.sentinel.response_machine_id
                     },
                 },
-                [mock.call("machine-id", mock.sentinel.response_machine_id)],
             ),
         ],
     )
     @mock.patch(M_PATH + "process_entitlements_delta")
-    @mock.patch(M_PATH + "UAConfig.write_cache")
+    @mock.patch("uaclient.files.state_files.machine_id_file.write")
     @mock.patch(M_PATH + "system.get_machine_id")
     @mock.patch("uaclient.files.MachineTokenFile.write")
     @mock.patch(M_PATH + "UAContractClient.update_contract_machine")
@@ -1271,10 +1278,9 @@ class TestRefresh:
         m_update_contract_machine,
         m_machine_token_file_write,
         m_get_machine_id,
-        m_write_cache,
+        m_machine_id_file_write,
         m_process_entitlements_deltas,
         update_contract_machine_result,
-        expected_write_cache_call_args,
         FakeConfig,
     ):
         m_entitlements.side_effect = [
@@ -1296,7 +1302,7 @@ class TestRefresh:
         assert [
             mock.call(update_contract_machine_result)
         ] == m_machine_token_file_write.call_args_list
-        assert expected_write_cache_call_args == m_write_cache.call_args_list
+        assert 1 == m_machine_id_file_write.call_count
         assert [
             mock.call(
                 mock.ANY,
