@@ -1,7 +1,5 @@
 import copy
 import datetime
-import os
-import stat
 import string
 
 import mock
@@ -13,7 +11,7 @@ from uaclient.entitlements import (
     entitlement_factory,
     valid_services,
 )
-from uaclient.entitlements.base import IncompatibleService
+from uaclient.entitlements.base import EntitlementWithMessage
 from uaclient.entitlements.entitlement_status import (
     ApplicationStatus,
     ContractStatus,
@@ -24,6 +22,7 @@ from uaclient.entitlements.fips import FIPSEntitlement
 from uaclient.entitlements.ros import ROSEntitlement
 from uaclient.entitlements.tests.test_base import ConcreteTestEntitlement
 from uaclient.files.notices import Notice, NoticesManager
+from uaclient.files.user_config_file import UserConfigData
 from uaclient.status import (
     DEFAULT_STATUS,
     TxtColor,
@@ -314,10 +313,12 @@ class TestStatus:
         return False
 
     @pytest.mark.parametrize("show_all", (True, False))
+    @mock.patch("uaclient.files.state_files.status_cache_file.write")
     @mock.patch("uaclient.status.get_available_resources")
     def test_root_unattached(
         self,
         m_get_available_resources,
+        _m_status_cache_file,
         _m_should_reboot,
         _m_remove_notice,
         m_on_supported_kernel,
@@ -397,6 +398,7 @@ class TestStatus:
             ),
         ),
     )
+    @mock.patch("uaclient.files.state_files.status_cache_file.write")
     @mock.patch(
         M_PATH + "livepatch.LivepatchEntitlement.application_status",
         return_value=(ApplicationStatus.DISABLED, ""),
@@ -406,6 +408,7 @@ class TestStatus:
         self,
         m_get_avail_resources,
         _m_livepatch_status,
+        _m_status_cache_file,
         _m_should_reboot,
         _m_remove_notice,
         m_on_supported_kernel,
@@ -497,13 +500,15 @@ class TestStatus:
         expected_services = [
             {
                 "description": cls.description,
-                "entitled": uf_entitled
-                if cls.name in resource_names
-                else default_entitled,
+                "entitled": (
+                    uf_entitled
+                    if cls.name in resource_names
+                    else default_entitled
+                ),
                 "name": cls.name,
-                "status": uf_status
-                if cls.name in resource_names
-                else default_status,
+                "status": (
+                    uf_status if cls.name in resource_names else default_status
+                ),
                 "status_details": mock.ANY,
                 "description_override": None,
                 "available": mock.ANY,
@@ -564,17 +569,25 @@ class TestStatus:
             m_get_cfg_status.return_value = DEFAULT_CFG_STATUS
             assert expected == status.status(cfg=cfg, show_all=True)
 
+    @mock.patch("uaclient.files.state_files.status_cache_file.write")
     @mock.patch("uaclient.util.we_are_currently_root")
     @mock.patch("uaclient.status.get_available_resources")
+    @mock.patch(
+        "uaclient.files.user_config_file.UserConfigFileObject.public_config",
+        new_callable=mock.PropertyMock,
+    )
     def test_nonroot_unattached_is_same_as_unattached_root(
         self,
+        m_public_config,
         m_get_available_resources,
         m_we_are_currently_root,
+        _m_status_cache_file,
         _m_should_reboot,
         _m_remove_notice,
         m_on_supported_kernel,
         FakeConfig,
     ):
+        m_public_config.return_value = UserConfigData()
         m_get_available_resources.return_value = [
             {"name": "esm-infra", "available": True}
         ]
@@ -588,17 +601,25 @@ class TestStatus:
 
         assert root_unattached_status == nonroot_status
 
+    @mock.patch("uaclient.files.state_files.status_cache_file.write")
     @mock.patch("uaclient.util.we_are_currently_root")
     @mock.patch("uaclient.status.get_available_resources")
+    @mock.patch(
+        "uaclient.files.user_config_file.UserConfigFileObject.public_config",
+        new_callable=mock.PropertyMock,
+    )
     def test_root_and_non_root_are_same_attached(
         self,
+        m_public_config,
         m_get_available_resources,
         m_we_are_currently_root,
+        _m_status_cache_file,
         _m_should_reboot,
         _m_remove_notice,
         m_on_supported_kernel,
         FakeConfig,
     ):
+        m_public_config.return_value = UserConfigData()
         m_we_are_currently_root.return_value = True
         root_cfg = FakeConfig.for_attached_machine()
         root_status = status.status(cfg=root_cfg)
@@ -607,22 +628,6 @@ class TestStatus:
         normal_status = status.status(cfg=normal_cfg)
         assert normal_status == root_status
 
-    @mock.patch("uaclient.status.get_available_resources", return_value=[])
-    def test_cache_file_is_written_world_readable(
-        self,
-        _m_get_available_resources,
-        _m_should_reboot,
-        m_remove_notice,
-        m_on_supported_kernel,
-        FakeConfig,
-    ):
-        cfg = FakeConfig()
-        status.status(cfg=cfg)
-
-        assert 0o644 == stat.S_IMODE(
-            os.lstat(cfg.data_path("status-cache")).st_mode
-        )
-
     @pytest.mark.parametrize("variants_in_contract", ((True), (False)))
     @pytest.mark.parametrize("show_all", (True, False))
     @pytest.mark.parametrize(
@@ -642,6 +647,7 @@ class TestStatus:
         ),
     )
     @pytest.mark.usefixtures("all_resources_available")
+    @mock.patch("uaclient.files.state_files.status_cache_file.write")
     @mock.patch(
         M_PATH + "fips.FIPSCommonEntitlement.application_status",
         return_value=(ApplicationStatus.DISABLED, ""),
@@ -672,6 +678,7 @@ class TestStatus:
         m_livepatch_uf_status,
         _m_livepatch_status,
         _m_fips_status,
+        _m_status_cache_file,
         _m_should_reboot,
         _m_remove_notice,
         m_on_supported_kernel,
@@ -871,18 +878,26 @@ class TestStatus:
         assert expected_calls == mock_notice.remove.call_args_list
 
     @pytest.mark.usefixtures("all_resources_available")
+    @mock.patch("uaclient.files.state_files.status_cache_file.write")
     @mock.patch("uaclient.util.we_are_currently_root")
     @mock.patch("uaclient.status.get_available_resources")
+    @mock.patch(
+        "uaclient.files.user_config_file.UserConfigFileObject.public_config",
+        new_callable=mock.PropertyMock,
+    )
     def test_expires_handled_appropriately(
         self,
+        m_public_config,
         _m_get_available_resources,
         m_we_are_currently_root,
+        _m_status_cache_file,
         _m_should_reboot,
         _m_remove_notice,
         m_on_supported_kernel,
         all_resources_available,
         FakeConfig,
     ):
+        m_public_config.return_value = UserConfigData()
         m_we_are_currently_root.return_value = True
         token = {
             "availableResources": all_resources_available,
@@ -927,20 +942,30 @@ class TestStatus:
         "uaclient.files.state_files.reboot_cmd_marker_file",
         new_callable=mock.PropertyMock,
     )
+    @mock.patch(
+        "uaclient.files.user_config_file.UserConfigFileObject.public_config",
+        new_callable=mock.PropertyMock,
+    )
+    @mock.patch("uaclient.files.state_files.status_cache_file.read")
+    @mock.patch("uaclient.files.state_files.status_cache_file.write")
     @mock.patch("uaclient.status.get_available_resources", return_value={})
     def test_nonroot_user_does_not_use_cache(
         self,
         _m_get_available_resources,
+        _m_status_cache_file_write,
+        m_status_cache_file_read,
+        m_public_config,
         m_reboot_cmd_marker_file,
         _m_should_reboot,
         m_remove_notice,
         m_on_supported_kernel,
         FakeConfig,
     ):
+        m_public_config.return_value = UserConfigData()
         m_reboot_cmd_marker_file.is_present = True
         cached_status = {"pass": True}
+        m_status_cache_file_read.return_value = cached_status
         cfg = FakeConfig()
-        cfg.write_cache("status-cache", cached_status)
         before = status.status(cfg=cfg)
 
         # Even non-root users can update execution_status details
@@ -1024,7 +1049,7 @@ class TestAttachedServiceStatus:
             ([], []),
             (
                 [
-                    IncompatibleService(
+                    EntitlementWithMessage(
                         FIPSEntitlement, messages.NamedMessage("code", "msg")
                     )
                 ],
@@ -1032,10 +1057,10 @@ class TestAttachedServiceStatus:
             ),
             (
                 [
-                    IncompatibleService(
+                    EntitlementWithMessage(
                         FIPSEntitlement, messages.NamedMessage("code", "msg")
                     ),
-                    IncompatibleService(
+                    EntitlementWithMessage(
                         ROSEntitlement, messages.NamedMessage("code2", "msg2")
                     ),
                 ],
